@@ -4,27 +4,23 @@
 #' data, and three-level data at the grand mean (CGM, i.e., grand mean centering)
 #' or within cluster (CWC, i.e., group mean centering).
 #'
-#' @param ...      a numeric vector for centering a predictor variable, or a
-#'                 data frame for centering more than one predictor. Alternatively,
-#'                 an expression indicating the variable names in \code{data} e.g.,
-#'                 \code{center(x1, x2, data = dat)}. Note that the operators
-#'                 \code{.}, \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
-#'                 and \code{!} can also be used to select variables, see 'Details'
-#'                 in the \code{\link{df.subset}} function.
-#' @param data     a data frame when specifying one or more predictor variables
-#'                 in the argument \code{...}. Note that the argument is \code{NULL}
-#'                 when specifying a numeric vector or data frame for the argument
-#'                 \code{...}.
-#' @param cluster  a character string indicating the name of the cluster
-#'                 variable in \code{...} or \code{data} for a two-level model,
-#'                 a character vector indicating the names of the cluster
-#'                 variables in \code{...} for a three-level model, or a vector
-#'                 or data frame representing the nested grouping structure
-#'                 (i.e., group or cluster variables). Alternatively, a
-#'                 character string or character vector indicating the variable
-#'                 name(s) of the cluster variable(s) in \code{data}. Note that
-#'                 the cluster variable at Level 3 come first in a three-level
-#'                 model, i.e., \code{cluster = c("level3", "level2")}.
+#' @param data     a numeric vector for centering a predictor variable, or a
+#'                 data frame for centering more than one predictor variable.
+#' @param ...      an expression indicating the variable names in \code{data} e.g.,
+#'                 \code{center(dat, x1, x2)} for centering the variables \code{x1}
+#'                 and \code{x2} in the data frame \code{dat}. Note that the
+#'                 operators \code{.}, \code{+}, \code{-}, \code{~}, \code{:},
+#'                 \code{::}, and \code{!} can also be used to select variables,
+#'                 see 'Details' in the \code{\link{df.subset}} function.
+#' @param cluster  a character string indicating the name of the cluster variable
+#'                 in \code{data} for a two-level model, a character vector
+#'                 indicating the names of the cluster variables in \code{data}
+#'                 for a three-level model, or a vector or data frame representing
+#'                 the nested grouping structure (i.e., group or cluster variables).
+#'                 Alternatively, a character string or character vector indicating
+#'                 the variable name(s) of the cluster variable(s) in \code{data}.
+#'                 Note that the cluster variable at Level 3 come first in a
+#'                 three-level model, i.e., \code{cluster = c("level3", "level2")}.
 #' @param type     a character string indicating the type of centering, i.e.,
 #'                 \code{"CGM"} for centering at the grand mean (i.e., grand mean
 #'                 centering, default when \code{cluster = NULL}) or \code{"CWC"}
@@ -33,7 +29,7 @@
 #' @param cwc.mean a character string indicating the type of centering of a level-1
 #'                 predictor variable in a three-level model, i.e., \code{L2}
 #'                 (default) for centering the predictor variable at the level-2
-#'                 cluster means, and  \code{L2} for centering the predictor
+#'                 cluster means, and  \code{L3} for centering the predictor
 #'                 variable at the level-3 cluster means.
 #' @param value    a numeric value for centering on a specific user-defined value.
 #'                 Note that this option is only available when specifying a
@@ -111,12 +107,12 @@
 #'
 #' L1 predictor variables are centered within cluster (CWC) by specifying
 #' \code{type = "CWC"} (Default). However, L1 predictor variables can be either
-#' centered within Level-2 cluster (\code{cwc.mean = "L2"}, Default,
+#' centered within Level-2 clusters (\code{cwc.mean = "L2"}, Default,
 #' see Brincks et al., 2017):
 #'
 #' \deqn{x_{ijk} - \bar{x}_{.jk}}
 #'
-#' or within Level-3 cluster (\code{cwc.mean = "L3"}, see Enders, 2013):
+#' or within Level-3 clusters (\code{cwc.mean = "L3"}, see Enders, 2013):
 #'
 #' \deqn{x_{ijk} - \bar{x}_{..k}}
 #'
@@ -148,8 +144,8 @@
 #'
 #' where \eqn{x_{..k}} is the predictor value of Level-3 cluster \eqn{k} and
 #' \eqn{\bar{x}_{...}} is the average Level-3 cluster score. Note that the cluster
-#' membership variable needs to be specified when centering a L3 predictor variable
-#' in three-level data.}
+#' membership variables at Level 2 and Level 3 need to be specified when centering
+#' a L3 predictor variable in three-level data.}
 #' }
 #'
 #' @author
@@ -168,7 +164,7 @@
 #' Chang, C.-N., & Kwok, O.-M. (2022) Partitioning Variance for a Within-Level
 #' Predictor in Multilevel Models. \emph{Structural Equation Modeling: A
 #' Multidisciplinary Journal}. Advance online publication.
-#' https://doi.org/10.1080/10705511.2022.2051175#'
+#' https://doi.org/10.1080/10705511.2022.2051175
 #'
 #' Enders, C. K. (2013). Centering predictors and cont
 #' extual effects. In M. A.
@@ -191,7 +187,7 @@
 #'
 #' @return
 #' Returns a numeric vector or data frame with the same length or same number of
-#' rows as \code{...} containing the centered variable(s).
+#' rows as \code{data} containing the centered variable(s).
 #'
 #' @export
 #'
@@ -199,23 +195,23 @@
 #' #----------------------------------------------------------------------------
 #' # Predictor Variables in Single-Level Data
 #'
-#' # Example 1: Center predictor 'disp' at the grand mean
+#' # Example 1a: Center predictor 'disp' at the grand mean
+#' center(mtcars, disp, append = FALSE)
+#'
+#' # Alternative specification without using the '...' argument
 #' center(mtcars$disp)
 #'
-#' # Alternative specification using the 'data' argument
-#' center(disp, data = mtcars)
+#' # Example 1b: Center predictors 'disp' and 'hp' at the grand mean and append to 'mtcars'
+#' center(mtcars, disp, hp)
 #'
-#' # Example 2: Center predictors 'disp' and 'hp' at the grand mean and append to 'mtcars'
+#' # Alternative specification without using the '...' argument
 #' cbind(mtcars, center(mtcars[, c("disp", "hp")]))
 #'
-#' # Alternative specification using the 'data' argument
-#' center(disp, hp, data = mtcars)
+#' # Example 1c: Center predictor 'disp' at the value 3
+#' center(mtcars, disp, value = 3)
 #'
-#' # Example 3: Center predictor 'disp' at the value 3
-#' center(disp, data = mtcars, value = 3)
-#'
-#' # Example 4: Center predictors 'disp' and 'hp' and label with the suffix ".v"
-#' center(disp, hp, data = mtcars, name = ".v")
+#' # Example 1d: Center predictors 'disp' and 'hp' and label with the suffix ".v"
+#' center(mtcars, disp, hp, name = ".v")
 #'
 #' #----------------------------------------------------------------------------
 #' # Predictor Variables in Two-Level Data
@@ -223,17 +219,17 @@
 #' # Load data set "Demo.twolevel" in the lavaan package
 #' data("Demo.twolevel", package = "lavaan")
 #'
-#' # Example 5: Center L1 predictor 'y1' within cluster
+#' # Example 2a: Center L1 predictor 'y1' within cluster
+#' center(Demo.twolevel, y1, cluster = "cluster")
+#'
+#' # Alternative specification without using the '...' argument
 #' center(Demo.twolevel$y1, cluster = Demo.twolevel$cluster)
 #'
-#' # Alternative specification using the 'data' argument
-#' center(y1, data = Demo.twolevel, cluster = "cluster")
+#' # Example 2b: Center L2 predictor 'w2' at the grand mean
+#' center(Demo.twolevel, w1, cluster = "cluster")
 #'
-#' # Example 6: Center L2 predictor 'w2' at the grand mean
-#' center(w1, data = Demo.twolevel, cluster = "cluster")
-#'
-#' # Example 6: Center L1 predictor 'y1' within cluster and L2 predictor 'w1' at the grand mean
-#' center(y1, w1, data = Demo.twolevel, cluster = "cluster")
+#' # Example 2c: Center L1 predictor 'y1' within cluster and L2 predictor 'w1' at the grand mean
+#' center(Demo.twolevel, y1, w1, cluster = "cluster")
 #'
 #' #----------------------------------------------------------------------------
 #' # Predictor Variables in Three-Level Data
@@ -242,27 +238,27 @@
 #' Demo.threelevel <- data.frame(Demo.twolevel, cluster2 = Demo.twolevel$cluster,
 #'                                              cluster3 = rep(1:10, each = 250))
 #'
-#' # Example 7a: Center L1 predictor 'y1' within L2 cluster
-#' center(y1, data = Demo.threelevel, cluster = c("cluster3", "cluster2"))
+#' # Example 3a: Center L1 predictor 'y1' within L2 cluster
+#' center(Demo.threelevel, y1, cluster = c("cluster3", "cluster2"))
 #'
-#' # Example 7b: Center L1 predictor 'y1' within L3 cluster
-#' center(y1, data = Demo.threelevel, cluster = c("cluster3", "cluster2"), cwc.mean = "L3")
+#' # Example 3b: Center L1 predictor 'y1' within L3 cluster
+#' center(Demo.threelevel, y1, cluster = c("cluster3", "cluster2"), cwc.mean = "L3")
 #'
-#' # Example 7b: Center L1 predictor 'y1' within L2 cluster and L2 predictor 'w1' within L3 cluster
-#' center(y1, w1, data = Demo.threelevel, cluster = c("cluster3", "cluster2"))
-center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
-                   cwc.mean = c("L2", "L3"), value = NULL,  append = TRUE,
+#' # Example 3c: Center L1 predictor 'y1' within L2 cluster and L2 predictor 'w1' within L3 cluster
+#' center(Demo.threelevel, y1, w1, cluster = c("cluster3", "cluster2"))
+center <- function(data, ..., cluster = NULL, type = c("CGM", "CWC"),
+                   cwc.mean = c("L2", "L3"), value = NULL, append = TRUE,
                    name = ".c", as.na = NULL, check = TRUE) {
 
   #_____________________________________________________________________________
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input '...' is missing
-  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
+  # Check if input 'data' is missing
+  if (isTRUE(missing(data))) { stop("Please specify a numeric vector or data frame for the argument 'data'", call. = FALSE) }
 
-  # Check if input '...' is NULL
-  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+  # Check if input 'data' is NULL
+  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
 
   #_____________________________________________________________________________
   #
@@ -271,16 +267,13 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Data using the argument 'data' ####
 
-  if (isTRUE(!is.null(data))) {
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(data), 1L, 3L))) { data <- as.data.frame(data) }
+  if (isTRUE(!missing(...))) {
 
     # Variable names
-    var.names <- .var.names(..., data = data, cluster = cluster, check.chr = "a matrix or data frame")
+    var.names <- .var.names(..., data = data, cluster = cluster)
 
-    # Extract data
-    x <- data[, var.names]
+    # Extract data and convert tibble into data frame or vector
+    x <- data[, var.names] |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
     # Cluster variable
     if (isTRUE(!is.null(cluster))) { cluster <- data[, cluster] }
@@ -290,22 +283,21 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
   } else {
 
-    # Extract data
-    x <- eval(..., enclos = parent.frame())
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(cluster), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(cluster)) == 1L)) { cluster <- unlist(cluster) } else { cluster <- as.data.frame(cluster) } }
-    if (isTRUE("tbl" %in% substr(class(x), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(x)) == 1L)) { x <- unlist(x) } else { x <- as.data.frame(x) } }
+    # Convert 'data' as tibble into data frame
+    x <- data |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
     # Data and cluster
     var.group <- .var.group(data = x, cluster = cluster)
 
     # Data
-    if (isTRUE(!is.null(var.group$data)))  { x <- var.group$data }
+    if (isTRUE(!is.null(var.group$data))) { x <- var.group$data }
 
     # Cluster variable
     if (isTRUE(!is.null(var.group$cluster))) { cluster <- var.group$cluster }
 
+    # Convert 'cluster' as tibble into data frame
+    if (isTRUE(!is.null(cluster) && "tbl" %in% substr(class(cluster), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(cluster)) == 1L)) { cluster <- unname(unlist(cluster)) } else { cluster <- as.data.frame(cluster) } }
+
   }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -350,7 +342,7 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
       if (isTRUE(!is.character(name))) { stop("Please specify a character string or vector for the argument 'name'.", call. = FALSE) }
 
-      if (isTRUE(length(name) > 1L && length(name) != ncol(as.data.frame(x)))) { stop("The length of the vector specified in 'name' does not match with the number of variable.", call. = FALSE) }
+      if (isTRUE(length(name) > 1L && length(name) != ncol(as.data.frame(x)))) { stop("Length of the vector specified in 'name' does not match with the number of variables.", call. = FALSE) }
 
     }
 
@@ -387,7 +379,7 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
           vartype <- "L1"
 
-          # Level 2 Variable
+        # Level 2 Variable
         } else {
 
           vartype = "L2"
@@ -430,8 +422,8 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
         type <- "CGM"
 
-        #...................
-        ### Multi ####
+      #...................
+      ### Multilevel ####
 
       } else {
 
@@ -440,7 +432,7 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
           type <- switch(vartype, L1 = "CWC", L2 = "CGM")
 
-          ##### Two cluster variable s
+        ##### Two cluster variable s
         } else if (isTRUE(no.clust == "two")) {
 
           type <- switch(vartype, L1 = "CWC", L2 = "CWC", L3 = "CGM")
@@ -485,9 +477,8 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
                  object <- as.numeric(scale(x, scale = FALSE))
 
-               },
                # Level 2 predictor
-               L2 = {
+               }, L2 = {
 
                  object <- x - mean(x[which(!duplicated(cluster))], na.rm = TRUE)
 
@@ -502,9 +493,8 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
                  object <- unname(x - misty::cluster.scores(x, cluster = cluster, fun = "mean", check = FALSE, expand = TRUE))
 
-               },
                # Level 2 predictor
-               L2 = {
+               }, L2 = {
 
                  # Note, level 2 predictor can only be centered at the grand mean
                  object <- x - mean(x[which(!duplicated(cluster))], na.rm = TRUE)
@@ -527,15 +517,13 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
                  object <- as.numeric(scale(x, scale = FALSE))
 
-               },
                # Level 2 predictor
-               L2 = {
+               }, L2 = {
 
                  object <- x - mean(x[which(!duplicated(apply(cluster, 1L, paste, collapse = "")))], na.rm = TRUE)
 
-               },
                # Level 3 predictor
-               L3 = {
+               }, L3 = {
 
                  object <- x - mean(x[which(!duplicated(cluster[, 1L]))], na.rm = TRUE)
 
@@ -549,36 +537,29 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
                L1 = {
 
                 switch(cwc.mean,
-                       # Deviation from the Leve-2 cluster mean
+                       # Deviation from the Level-2 cluster mean
                        L2 = {
 
                          object <- unname(x - misty::cluster.scores(x, cluster = apply(cluster, 1L, paste, collapse = ""), fun = "mean", check = FALSE, expand = TRUE))
 
-                       },
-                       # Deviation from the Leve-3 cluster mean
-                       L3 = {
+                       # Deviation from the Level-3 cluster mean
+                       }, L3 = {
 
                          object <- x - misty::cluster.scores(x, cluster = cluster[, 1L])
 
                        })
 
-               },
                # Level 2 predictor
-               L2 = {
+               }, L2 = {
 
-                 x.cluster <- data.frame(x, cluster3 = cluster[, 1L], cluster2 = cluster[, 2])
+                 object <- (data.frame(x, cluster3 = cluster[, 1L], cluster2 = cluster[, 2]) |>
+                              (\(y) misty::cluster.scores(y[!duplicated(y$cluster2), ], x, cluster = "cluster3"))() |>
+                              (\(z) data.frame(z, object = z$x - z$x.a))() |>
+                              (\(q) merge(data.frame(by = apply(cluster[, c("cluster3", "cluster2")], 1L, paste, collapse = "")),
+                                          data.frame(object = q$object, by = apply(q[, c("cluster3", "cluster2")], 1L, paste, collapse = "")), by = "by", sort = FALSE))())[, "object"]
 
-                 x.cluster.u <- misty::cluster.scores(x, data = x.cluster[!duplicated(x.cluster$cluster2), ], cluster = "cluster3")
-
-                 x.cluster.u$object <- x.cluster.u$x - x.cluster.u$x.a
-
-                 x.cluster <- merge(x.cluster, x.cluster.u[, c("object", "cluster2")], by = "cluster2")
-
-                 object <- x.cluster[match(cluster[, 2], x.cluster[, "cluster2"]), "object"]
-
-               },
                # Level 3 predictor
-               L3 = {
+               }, L3 = {
 
                  # Note, level 3 predictor can only be centered at the grand mean
                  object <- x - mean(x[which(!duplicated(cluster[, 1L]))], na.rm = TRUE)
@@ -594,8 +575,7 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
 
   } else {
 
-    object <- data.frame(vapply(x, misty::center, cluster = cluster, type = type, cwc.mean = cwc.mean, value = value, as.na = as.na, check = FALSE,
-                                FUN.VALUE = double(nrow(x))))
+    object <- data.frame(vapply(x, misty::center, cluster = cluster, type = type, cwc.mean = cwc.mean, value = value, as.na = as.na, check = FALSE, FUN.VALUE = double(nrow(x))))
 
     #...................
     ### Variable names ####
@@ -615,7 +595,7 @@ center <- function(..., data = NULL, cluster = NULL, type = c("CGM", "CWC"),
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Append ####
 
-  if (isTRUE(!is.null(data) && append)) {
+  if (isTRUE(!missing(...) && append)) {
 
     if (isTRUE(is.null(dim(x)))) {
 
