@@ -2,25 +2,20 @@
 #'
 #' This function computes group means by default.
 #'
-#' @param ...     a numeric vector for computing cluster scores for a variable,
-#'                matrix or data frame for computing cluster scores for more than
-#'                one variable. Alternatively, an expression indicating the variable
-#'                names in \code{data} e.g., \code{ci.mean(x1, x2, data = dat)}.
-#'                Note that the operators \code{.}, \code{+}, \code{-}, \code{~},
+#' @param data    a numeric vector for centering a predictor variable, or a
+#'                data frame for centering more than one predictor variable.
+#' @param ...     an expression indicating the variable names in \code{data} e.g.,
+#'                \code{cluster.scores(dat, x1, x2, cluster = "cluster")}. Note
+#'                that the operators \code{.}, \code{+}, \code{-}, \code{~},
 #'                \code{:}, \code{::}, and \code{!} can also be used to select
 #'                variables, see 'Details' in the \code{\link{df.subset}} function.
-#' @param data    a data frame when specifying one or more variables in the
-#'                argument \code{...}. Note that the argument is \code{NULL}
-#'                when specifying a numeric vector, matrix, or data frame for
-#'                the argument \code{...}.
-#' @param cluster either a character string indicating the variable name of
-#'                the cluster variable in \code{...} or \code{data}, or a
-#'                vector representing the nested grouping structure (i.e.,
-#'                group or cluster variable).
+#' @param cluster a character string indicating the variable name of the cluster
+#'                variable in \code{data}, or a vector representing the nested
+#'                grouping structure (i.e., group or cluster variable).
 #' @param fun     character string indicating the function used to compute group
 #'                scores, default: \code{"mean"}.
-#' @param expand  logical: if \code{TRUE} (default), vector of cluster scores is expanded
-#'                to match the input vector \code{x}.
+#' @param expand  logical: if \code{TRUE} (default), vector of cluster scores is
+#'                expanded to match the input vector \code{data}.
 #' @param append  logical: if \code{TRUE} (default), cluster scores are appended
 #'                to the data frame specified in the argument \code{data}.
 #' @param name    a character string or character vector indicating the names
@@ -28,11 +23,11 @@
 #'                the ending \code{".a"} resulting in e.g. \code{"x1.a"} and
 #'                \code{"x2.a"}. Variable names can also be specified using a
 #'                character vector matching the number of variables specified in
-#'                \code{x} (e.g., \code{name = c("cluster.x1", "cluster.x2")}).
+#'                \code{data} (e.g., \code{name = c("cluster.x1", "cluster.x2")}).
 #' @param as.na   a numeric vector indicating user-defined missing values, i.e.
 #'                these values are converted to \code{NA} before conducting the
 #'                analysis. Note that \code{as.na()} function is only applied to
-#'                the argument \code{x}, but not to \code{cluster}.
+#'                the argument \code{data}, but not to \code{cluster}.
 #' @param check   logical: if \code{TRUE} (default), argument specification is checked.
 #'
 #' @author
@@ -52,7 +47,7 @@
 #'
 #' @return
 #' Returns a numeric vector or data frame containing cluster scores with the same
-#' length or same number of rows as \code{x} if \code{expand = TRUE} or with the
+#' length or same number of rows as \code{data} if \code{expand = TRUE} or with the
 #' length or number of rows as \code{length(unique(cluster))} if \code{expand = FALSE}.
 #'
 #' @export
@@ -62,25 +57,25 @@
 #' data("Demo.twolevel", package = "lavaan")
 #'
 #' # Example 1: Compute cluster means for 'y1' and expand to match the input 'y1'
-#' cluster.scores(Demo.twolevel$y1, cluster = Demo.twolevel$cluster)
+#' cluster.scores(Demo.twolevel, y1, cluster = "cluster", append = FALSE)
 #'
-#' # Alternative specification using the 'data' argument
-#' cluster.scores(y1, data = Demo.twolevel, cluster = "cluster")
+#' # Alternative specification without using the '...' argument
+#' cluster.scores(Demo.twolevel$y1, cluster = Demo.twolevel$cluster)
 #'
 #' # Example 2: Compute standard deviation for each cluster
 #' # and expand to match the input x
-#' cluster.scores(Demo.twolevel$y1, cluster = Demo.twolevel$cluster, fun = "sd")
+#' cluster.scores(Demo.twolevel, cluster = "cluster", fun = "sd")
 #'
 #' # Example 3: Compute cluster means without expanding the vector
-#' cluster.scores(Demo.twolevel$y1, cluster = Demo.twolevel$cluster, expand = FALSE)
+#' cluster.scores(Demo.twolevel, cluster = "cluster", expand = FALSE)
 #'
 #' # Example 4: Compute cluster means for 'y1' and 'y2' and append to 'Demo.twolevel'
+#' cluster.scores(Demo.twolevel, y1, y2, cluster = "cluster")
+#'
+#' # Alternative specification without using the '...' argument
 #' cbind(Demo.twolevel,
 #'       cluster.scores(Demo.twolevel[, c("y1", "y2")], cluster = Demo.twolevel$cluster))
-#'
-#' # Alternative specification using the 'data' argument
-#' cluster.scores(y1, y2, data = Demo.twolevel, cluster = "cluster")
-cluster.scores <- function(..., data = NULL, cluster,
+cluster.scores <- function(data, ..., cluster,
                            fun = c("mean", "sum", "median", "var", "sd", "min", "max"),
                            expand = TRUE, append = TRUE, name = ".a", as.na = NULL,
                            check = TRUE) {
@@ -89,11 +84,11 @@ cluster.scores <- function(..., data = NULL, cluster,
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input '...' is missing
-  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
+  # Check if input 'data' is missing
+  if (isTRUE(missing(data))) { stop("Please specify a numeric vector or data frame for the argument 'data'", call. = FALSE) }
 
-  # Check if input '...' is NULL
-  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+  # Check if input 'data' is NULL
+  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
 
   # Check input 'cluster'
   if (isTRUE(missing(cluster))) { stop("Please specify a variable name or vector representing the grouping structure for the argument 'cluster'.", call. = FALSE) }
@@ -108,16 +103,13 @@ cluster.scores <- function(..., data = NULL, cluster,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Data using the argument 'data' ####
 
-  if (isTRUE(!is.null(data))) {
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(data), 1L, 3L))) { data <- as.data.frame(data) }
+  if (isTRUE(!missing(...))) {
 
     # Variable names
-    var.names <- .var.names(..., data = data, check.chr = "a numeric vector, matrix, or data frame")
+    var.names <- .var.names(..., data = data, cluster = cluster)
 
-    # Extract data
-    x <- data[, var.names]
+    # Extract data and convert tibble into data frame or vector
+    x <- data[, var.names] |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
     # Cluster variable
     cluster <- data[, cluster]
@@ -127,11 +119,8 @@ cluster.scores <- function(..., data = NULL, cluster,
 
   } else {
 
-    # Extract data
-    x <- eval(..., enclos = parent.frame())
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(x), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(x)) == 1L)) { x <- unlist(x) } else { x <- as.data.frame(x) } }
+    # Convert 'data' as tibble into data frame
+    x <- data |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
     # Data and cluster
     var.group <- .var.group(data = x, cluster = cluster)
@@ -144,49 +133,50 @@ cluster.scores <- function(..., data = NULL, cluster,
 
   }
 
+  # Convert 'cluster' as tibble into data frame
+  if (isTRUE(!is.null(cluster) && "tbl" %in% substr(class(cluster), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(cluster)) == 1L)) { cluster <- unname(unlist(cluster)) } else { cluster <- as.data.frame(cluster) } }
+
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Check input 'cluster' ####
+  ## Convert user-missing values into NA ####
 
-  if (isTRUE(nrow(data.frame(cluster)) != nrow(data.frame(x)))) { stop("The length of the vector in 'cluster' does not match with the length of the vector in 'x'.", call. = FALSE) }
-
-  # Check if only one variable specified in the input 'cluster'
-  if (isTRUE(ncol(data.frame(cluster)) != 1L)) { stop("More than one variable specified for the argument 'cluster'.", call. = FALSE) }
-
-  # Convert 'cluster' into a vector
-  cluster <- unlist(cluster, use.names = FALSE)
+  if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
 
   #_____________________________________________________________________________
   #
   # Input Check ----------------------------------------------------------------
 
-  # Check inputs
-  .check.input(logical = c("expand", "append"),
-               m.character = list(fun = c("mean", "sum", "median", "var", "sd", "min", "max")), envir = environment(), input.check = check)
+  .check.input(logical = c("expand", "append"), m.character = list(fun = c("mean", "sum", "median", "var", "sd", "min", "max")), envir = environment(), input.check = check)
 
   # Additional checks
   if (isTRUE(check)) {
 
-    # Check input 'x'
+    # Check input 'data'
     if (isTRUE(any(c(vapply(data.frame(x), mode, FUN.VALUE = character(1L)) != "numeric", vapply(data.frame(x), is.factor, FUN.VALUE = logical(1L)))))) {
 
       if (isTRUE(is.null(dim(x)))) {
 
-        stop("Please specify a numeric vector for the argument 'x'.", call. = FALSE)
+        stop("Please specify a numeric vector for the argument 'data'.", call. = FALSE)
 
       } else {
 
-        stop("Please specify a matrix or data frame with numeric vectors for the argument 'x'.", call. = FALSE)
+        stop("Please specify a data frame with numeric vectors for the argument 'data'.", call. = FALSE)
 
       }
 
     }
 
+    # Check if only one variable specified in the input 'cluster'
+    if (isTRUE(ncol(data.frame(cluster)) != 1L)) { stop("Please specify one cluster variable for the argument 'cluster'.", call. = FALSE) }
+
+    # Check input length of 'data' and 'cluster'
+    if (isTRUE(nrow(data.frame(cluster)) != nrow(data.frame(x)))) { stop("The length of the vector in 'cluster' does not match with the length of the vector in 'data'.", call. = FALSE) }
+
     # Check input 'name'
     if (isTRUE(!is.null(dim(x)))) {
 
       if (isTRUE(!is.character(name))) { stop("Please specify a character string or vector for the argument 'name'.", call. = FALSE) }
 
-      if (isTRUE(length(name) > 1L && length(name) != ncol(x))) {  stop("The length of the vector specified in 'name' does not match with the number of variable in 'x'.", call. = FALSE) }
+      if (isTRUE(length(name) > 1L && length(name) != ncol(x))) {  stop("The length of the vector specified in 'name' does not match with the number of variable in 'data'.", call. = FALSE) }
 
     }
 
@@ -196,21 +186,11 @@ cluster.scores <- function(..., data = NULL, cluster,
   #
   # Arguments ------------------------------------------------------------------
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Convert matrix into data frame ####
-
-  if (is.matrix(x)) { x <- data.frame(x) }
-
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Function for computing cluster scores ####
 
   fun <- ifelse(all(c("mean", "sum", "median", "var", "sd", "min", "max") %in% fun), "mean", fun)
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Convert user-missing values into NA ####
-
-  if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
-
   #_____________________________________________________________________________
   #
   # Main Function --------------------------------------------------------------
@@ -288,7 +268,7 @@ cluster.scores <- function(..., data = NULL, cluster,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Append ####
 
-  if (isTRUE(!is.null(data) && expand && append)) {
+  if (isTRUE(!missing(...) && expand && append)) {
 
     if (isTRUE(is.null(dim(x)))) {
 
