@@ -157,593 +157,129 @@
 #' @return
 #' Returns an object of class \code{misty.object}, which is a list with following
 #' entries:
-#' \tabular{ll}{
-#' \code{call} \tab function call \cr
-#' \code{type} \tab type of analysis \cr
-#' \code{sample} \tab type of sample, i.e., one-, two-, or, paired-sample \cr
-#' \code{data} \tab matrix or data frame specified in \code{x}  \cr
-#' \code{args} \tab specification of function arguments \cr
-#' \code{result} \tab result table \cr
-#' }
+#'
+#' \item{\code{call}}{function call}
+#' \item{\code{type}}{type of analysis}
+#' \item{\code{sample}}{type of sample, i.e., one-, two-, or, paired-sample}
+#' \item{\code{data}}{matrix or data frame specified in \code{x}  }
+#' \item{\code{args}}{specification of function arguments}
+#' \item{\code{result}}{result table}
 #'
 #' @export
 #'
 #' @examples
-#' dat1 <- data.frame(group1 = c(1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2,
-#'                               1, 2, 2, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 1),
-#'                    group2 = c(1, 2, 1, 1, 1, 2, 1, 2, 1, 2, 1, 2, 2, 2,
-#'                               1, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 2),
-#'                    group3 = c(1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 2, 1, 1, 1,
-#'                               1, 2, 2, 2, 1, 2, 1, 2, 1, 2, 1, 2, 1, 1),
-#'                    x1 = c(3, 2, 5, 3, 6, 3, 2, 4, 6, 5, 3, 3, 5, 4,
-#'                           4, 3, 5, 3, 2, 3, 3, 6, 6, 7, 5, 6, 6, 4),
-#'                    x2 = c(4, 4, 3, 6, 4, 7, 3, 5, 3, 3, 4, 2, 3, 6,
-#'                           3, 5, 2, 6, 8, 3, 2, 5, 4, 5, 3, 2, 2, 4),
-#'                    x3 = c(7, 6, 5, 6, 4, 2, 8, 3, 6, 1, 2, 5, 8, 6,
-#'                           2, 5, 3, 1, 6, 4, 5, 5, 3, 6, 3, 2, 2, 4))
-#'
 #' #----------------------------------------------------------------------------
 #' # One-sample design
 #'
-#' # Example 1: Cohen's d.z with two-sided 95% CI
+#' # Example 1a: Cohen's d.z with two-sided 95% CI
 #' # population mean = 3
-#' cohens.d(dat1$x1, mu = 3)
+#' cohens.d(mtcars$mpg, mu = 20)
 #'
-#' # Example 2: Cohen's d.z (aka Hedges' g.z) with two-sided 95% CI
+#' # Example 1b: Cohen's d.z (aka Hedges' g.z) with two-sided 95% CI
 #' # population mean = 3, with small sample correction factor
-#' cohens.d(dat1$x1, mu = 3, correct = TRUE)
+#' cohens.d(mtcars$mpg, mu = 20, correct = TRUE)
 #'
-#' # Example 3: Cohen's d.z for more than one variable with two-sided 95% CI
-#' # population mean = 3
-#' cohens.d(dat1[, c("x1", "x2", "x3")], mu = 3)
+#' # Example 1c: Cohen's d.z with two-sided 95% CI
+#' # population mean = 3, by 'vs' separately
+#' cohens.d(mtcars$mpg, mu = 20, group = mtcars$vs)
 #'
-#' # Example 4: Cohen's d.z with two-sided 95% CI
-#' # population mean = 3, by group1 separately
-#' cohens.d(dat1$x1, mu = 3, group = dat1$group1)
+#' # Example 1d: Cohen's d.z with two-sided 95% CI
+#' # population mean = 20, split analysis by 'vs'
+#' cohens.d(mtcars$mpg, mu = 20, split = mtcars$vs)
 #'
-#' # Example 5: Cohen's d.z for more than one variable with two-sided 95% CI
-#' # population mean = 3, by group1 separately
-#' cohens.d(dat1[, c("x1", "x2", "x3")], mu = 3, group = dat1$group1)
-#'
-#' # Example 6: Cohen's d.z with two-sided 95% CI
-#' # population mean = 3, split analysis by group1
-#' cohens.d(dat1$x1, mu = 3, split = dat1$group1)
-#'
-#' # Example 7: Cohen's d.z for more than one variable with two-sided 95% CI
-#' # population mean = 3, split analysis by group1
-#' cohens.d(dat1[, c("x1", "x2", "x3")], mu = 3, split = dat1$group1)
-#'
-#' # Example 8: Cohen's d.z with two-sided 95% CI
-#' # population mean = 3, by group1 separately1, split by group2
-#' cohens.d(dat1$x1, mu = 3, group = dat1$group1, split = dat1$group2)
-#'
-#' # Example 9: Cohen's d.z for more than one variable with two-sided 95% CI
-#' # population mean = 3, by group1 separately1, split by group2
-#' cohens.d(dat1[, c("x1", "x2", "x3")], mu = 3, group = dat1$group1,
-#'          split = dat1$group2)
+#' # Example 1e: Cohen's d.z with two-sided 95% CI
+#' # population mean = 3, by 'vs' separately, split by 'am'
+#' cohens.d(mtcars$mpg, mu = 20, group = mtcars$vs, split = mtcars$am)
 #'
 #' #----------------------------------------------------------------------------
 #' # Two-sample design
 #'
-#' # Example 10: Cohen's d.s with two-sided 95% CI
+#' # Example 2a: Cohen's d.s with two-sided 95% CI
 #' # weighted pooled SD
-#' cohens.d(x1 ~ group1, data = dat1)
+#' cohens.d(mpg ~ vs, data = mtcars)
 #'
-#' # Example 11: Cohen's d.s with two-sided 99% CI
+#' # Example 2b: Cohen's d.s with two-sided 99% CI
 #' # weighted pooled SD
-#' cohens.d(x1 ~ group1, data = dat1, conf.level = 0.99)
+#' cohens.d(mpg ~ vs, data = mtcars, conf.level = 0.99)
 #'
-#' # Example 12: Cohen's d.s with one-sided 99% CI
+#' # Example 2c: Cohen's d.s with one-sided 99% CI
 #' # weighted pooled SD
-#' cohens.d(x1 ~ group1, data = dat1, alternative = "greater")
+#' cohens.d(mpg ~ vs, data = mtcars, alternative = "greater", conf.level = 0.99)
 #'
-#' # Example 13: Cohen's d.s with two-sided 99% CI
+#' # Example 2d: Cohen's d.s for more than one variable with two-sided 95% CI
 #' # weighted pooled SD
-#' cohens.d(x1 ~ group1, data = dat1, conf.level = 0.99)
+#' cohens.d(cbind(mpg, disp, hp) ~ vs, data = mtcars)
 #'
-#' # Example 14: Cohen's d.s with one-sided 95%% CI
-#' # weighted pooled SD
-#' cohens.d(x1 ~ group1, data = dat1, alternative = "greater")
-#'
-#' # Example 15: Cohen's d.s for more than one variable with two-sided 95% CI
-#' # weighted pooled SD
-#' cohens.d(cbind(x1, x2, x3) ~ group1, data = dat1)
-#'
-#' # Example 16: Cohen's d with two-sided 95% CI
+#' # Example 2e: Cohen's d with two-sided 95% CI
 #' # unweighted SD
-#' cohens.d(x1 ~ group1, data = dat1, weighted = FALSE)
+#' cohens.d(mpg ~ vs, data = mtcars, weighted = FALSE)
 #'
-#' # Example 17: Cohen's d.s (aka Hedges' g.s) with two-sided 95% CI
+#' # Example 2f: Cohen's d.s (aka Hedges' g.s) with two-sided 95% CI
 #' # weighted pooled SD, with small sample correction factor
-#' cohens.d(x1 ~ group1, data = dat1, correct = TRUE)
+#' cohens.d(mpg ~ vs, data = mtcars, correct = TRUE)
 #'
-#' # Example 18: Cohen's d (aka Hedges' g) with two-sided 95% CI
+#' # Example 2g: Cohen's d (aka Hedges' g) with two-sided 95% CI
 #' # Unweighted SD, with small sample correction factor
-#' cohens.d(x1 ~ group1, data = dat1, weighted = FALSE, correct = TRUE)
+#' cohens.d(mpg ~ vs, data = mtcars, weighted = FALSE, correct = TRUE)
 #'
-#' # Example 19: Cohen's d (aka Glass's delta) with two-sided 95% CI
+#' # Example 2h: Cohen's d (aka Glass's delta) with two-sided 95% CI
 #' # SD of reference group 1
-#' cohens.d(x1 ~ group1, data = dat1, ref = 1)
+#' cohens.d(mpg ~ vs, data = mtcars, ref = 0)
 #'
-#' # Example 20: Cohen's d.s with two-sided 95% CI
-#' # weighted pooled SD, by group2 separately
-#' cohens.d(x1 ~ group1, data = dat1, group = dat1$group2)
+#' # Example 2i: Cohen's d.s with two-sided 95% CI
+#' # weighted pooled SD, by 'am' separately
+#' cohens.d(mpg ~ vs, data = mtcars, group = mtcars$am)
 #'
-#' # Example 21: Cohen's d.s for more than one variable with two-sided 95% CI
-#' # weighted pooled SD, by group2 separately
-#' cohens.d(cbind(x1, x2, x3) ~ group1, data = dat1, group = dat1$group2)
-#'
-#' # Example 22: Cohen's d.s with two-sided 95% CI
-#' # weighted pooled SD, split analysis by group2
-#' cohens.d(x1 ~ group1, data = dat1, split = dat1$group2)
-#'
-#' # Example 23: Cohen's d.s for more than one variable with two-sided 95% CI
-#' # weighted pooled SD, split analysis by group2
-#' cohens.d(cbind(x1, x2, x3) ~ group1, data = dat1, split = dat1$group2)
-#'
-#' # Example 24: Cohen's d.s with two-sided 95% CI
-#' # weighted pooled SD, by group2 separately, split analysis by group3
-#' cohens.d(x1 ~ group1, data = dat1,
-#'          group = dat1$group2, split = dat1$group3)
-#'
-#' # Example 25: Cohen's d.s for more than one variable with two-sided 95% CI
-#' # weighted pooled SD, by group2 separately, split analysis by group3
-#' cohens.d(cbind(x1, x2, x3) ~ group1, data = dat1,
-#'          group = dat1$group2, split = dat1$group3)
+#' # Example 2j: Cohen's d.s with two-sided 95% CI
+#' # weighted pooled SD, split analysis by 'am'
+#' cohens.d(mpg ~ vs, data = mtcars, split = mtcars$am)
 #'
 #' #----------------------------------------------------------------------------
 #' # Paired-sample design
 #'
-#' # Example 26: Cohen's d.z with two-sided 95% CI
+#' # Example 3a: Cohen's d.z with two-sided 95% CI
 #' # SD of the difference scores
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE)
 #'
-#' # Example 27: Cohen's d.z with two-sided 99% CI
+#' # Example 3b: Cohen's d.z with one-sided 99% CI
 #' # SD of the difference scores
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, conf.level = 0.99)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, alternative = "greater",
+#'          conf.level = 0.99)
 #'
-#' # Example 28: Cohen's d.z with one-sided 95% CI
-#' # SD of the difference scores
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, alternative = "greater")
-#'
-#' # Example 29: Cohen's d.rm with two-sided 95% CI
+#' # Example 3c: Cohen's d.rm with two-sided 95% CI
 #' # controlling for the correlation between measures
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, weighted = FALSE)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, weighted = FALSE)
 #'
-#' # Example 30: Cohen's d.av with two-sided 95% CI
+#' # Example 3d: Cohen's d.av with two-sided 95% CI
 #' # without controlling for the correlation between measures
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, weighted = FALSE, cor = FALSE)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, weighted = FALSE, cor = FALSE)
 #'
-#' # Example 31: Cohen's d.z (aka Hedges' g.z) with two-sided 95% CI
+#' # Example 3e: Cohen's d.z (aka Hedges' g.z) with two-sided 95% CI
 #' # SD of the differnece scores
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, correct = TRUE)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, correct = TRUE)
 #'
-#' # Example 32: Cohen's d.rm (aka Hedges' g.rm) with two-sided 95% CI
+#' # Example 3f: Cohen's d.rm (aka Hedges' g.rm) with two-sided 95% CI
 #' # controlling for the correlation between measures
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, weighted = FALSE, correct = TRUE)
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, weighted = FALSE, correct = TRUE)
 #'
-#' # Example 33: Cohen's d.av (aka Hedges' g.av) with two-sided 95% CI
+#' # Example 3g: Cohen's d.av (aka Hedges' g.av) with two-sided 95% CI
 #' # without controlling for the correlation between measures
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, weighted = FALSE, cor = FALSE,
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, weighted = FALSE, cor = FALSE,
 #'          correct = TRUE)
 #'
-#' # Example 34: Cohen's d.z with two-sided 95% CI
-#' # SD of the difference scores, by group1 separately
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, group = dat1$group1)
+#' # Example 3h: Cohen's d.z with two-sided 95% CI
+#' # SD of the difference scores, by 'vs' separately
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, group = mtcars$vs)
 #'
-#' # Example 35:  Cohen's d.z with two-sided 95% CI
-#' # SD of the difference scores, split analysis by group1
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE, split = dat1$group1)
-#'
-#' # Example 36: Cohen's d.z with two-sided 95% CI
-#' # SD of the difference scores, by group1 separately, split analysis by group2
-#' cohens.d(dat1$x1, dat1$x2, paired = TRUE,
-#'          group = dat1$group1, split = dat1$group2)
+#' # Example 3i:  Cohen's d.z with two-sided 95% CI
+#' # SD of the difference scores, split analysis by 'vs'
+#' cohens.d(mtcars$drat, mtcars$wt, paired = TRUE, split = mtcars$vs)
 cohens.d <- function(x, ...) {
 
   UseMethod("cohens.d")
 
 }
 
-#_______________________________________________________________________________
-#
-# Cohen's d function -----------------------------------------------------------
-
-.internal.d.function <- function(x, y, mu, paired, weighted, cor, ref, correct,
-                                 alternative, conf.level) {
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## One-sample ####
-  if (isTRUE(is.null(y))) {
-
-    # Unstandardized mean difference
-    yx.diff <- mean(x, na.rm = TRUE) - mu
-
-    # Standard deviation
-    sd.group <- x.sd <- sd(x, na.rm = TRUE)
-
-    # Sample size
-    x.n <- length(na.omit(x))
-
-    #...................
-    ### Cohen's d ####
-
-    d <- yx.diff / sd.group
-
-    #...................
-    ### Correction factor ####
-
-    # Bias-corrected Cohen's d
-    if (isTRUE(correct)) {
-
-      v <- x.n - 1
-
-      # Correction factor based on gamma function
-      corr.factor <- gamma(0.5*v) / ((sqrt(v / 2L)) * gamma(0.5 * (v - 1L)))
-
-      # Correction factor based on approximation method
-      if (isTRUE(is.na(corr.factor) || is.nan(corr.factor) || is.infinite(corr.factor))) {
-
-        corr.factor <- (1L - (3L / (4L * v - 1L)))
-
-      }
-
-      d <- d*corr.factor
-
-    }
-
-    #...................
-    ### Confidence interval ####
-
-    # Standard error
-    d.se <- sqrt((x.n / (x.n / 2L)^2L) + 0.5*(d^2L / x.n))
-
-    # Noncentrality parameter
-    t <- yx.diff / (x.sd / sqrt(x.n))
-    df <- x.n - 1
-
-    conf1 <- ifelse(alternative == "two.sided", (1L + conf.level) / 2L, conf.level)
-    conf2 <- ifelse(alternative == "two.sided", (1L - conf.level) / 2L, 1L - conf.level)
-
-    st <- max(0.1, abs(t))
-
-    ###
-
-    end1 <- t
-    while(suppressWarnings(pt(q = t, df = df, ncp = end1)) < conf1) { end1 <- end1 - st }
-
-    ncp1 <- uniroot(function(x) conf1 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(end1, 2*t - end1))$root
-
-    ###
-
-    end2 <- t
-    while(suppressWarnings(pt(q = t, df = df, ncp = end2)) > conf2) { end2 <- end2 + st }
-
-    ncp2 <- uniroot(function(x) conf2 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(2*t - end2, end2))$root
-
-    # Confidence interval around ncp
-    conf.int <- switch(alternative,
-                       two.sided = c(low = ncp1 / sqrt(df), upp = ncp2 / sqrt(df)),
-                       less = c(low = -Inf, upp = ncp2 / sqrt(df)),
-                       greater = c(low = ncp1 / sqrt(df), upp = Inf))
-
-    # With correction factor
-    if(isTRUE(correct)) {
-
-      conf.int <- conf.int*corr.factor
-
-    }
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Two-sample ####
-  } else if (!isTRUE(paired)) {
-
-    #...................
-    ### Data ####
-
-    # x and y
-    x <- na.omit(x)
-    y <- na.omit(y)
-
-    # Sample size for x and y
-    x.n <- length(x)
-    y.n <- length(y)
-
-    # Total sample size
-    xy.n <- sum(c(x.n, y.n))
-
-    # Unstandardized mean difference
-    yx.diff <- mean(y) - mean(x)
-
-    # Variance
-    x.var <- var(x)
-    y.var <- var(y)
-
-    # Standard deviation
-    x.sd <- sd(x)
-    y.sd <- sd(y)
-
-    # At least 2 observations for x/y and variance in x/y
-    if (isTRUE((x.n >= 2L && y.n >= 2L) && (x.var != 0L && y.var != 0L))) {
-
-      #...................
-      ### Standard deviation ####
-
-      # Pooled standard deviation
-      if (isTRUE(is.null(ref))) {
-
-        # Weighted pooled standard deviation, Cohen's d.s
-        if (isTRUE(weighted)) {
-
-          sd.group <- sqrt(((x.n - 1L)*x.var + (y.n - 1L)*y.var) / (xy.n - 2L))
-
-        # Unweighted pooled standard deviation
-        } else {
-
-          sd.group <- sqrt(sum(c(x.var, y.var)) / 2L)
-
-        }
-
-      # Standard deviation from reference group x or y, Glass's delta
-      } else {
-
-        sd.group <- ifelse(ref == "x", x.sd, y.sd)
-
-      }
-
-      #...................
-      ### Cohen's d ####
-
-      d <- yx.diff / sd.group
-
-      #...................
-      ### Correction factor ####
-
-      # Bias-corrected Cohen's d, i.e., Hedges' g
-      if (isTRUE(correct)) {
-
-        # Degrees of freedom
-        v <- xy.n - 2L
-
-        # Correction factor based on gamma function
-        corr.factor <- gamma(0.5*v) / ((sqrt(v / 2L)) * gamma(0.5 * (v - 1L)))
-
-        # Correction factor based on approximation method
-        if (isTRUE(is.na(corr.factor) || is.nan(corr.factor) || is.infinite(corr.factor))) {
-
-          corr.factor <- (1L - (3L / (4L * v - 1L)))
-
-        }
-
-        # Applying correction factor
-        d <- d*corr.factor
-
-      }
-
-      #...................
-      ### Confidence interval ####
-
-      # No reference group
-      if (isTRUE(is.null(ref))) {
-
-        # Cohen's d.s
-
-        # Pooled standard deviation
-        if (isTRUE(weighted)) {
-
-          d.se <- sd.group * sqrt(1 / x.n + 1 / y.n)
-          df <- xy.n - 2
-
-        # Unpooled standard deviation
-        } else {
-
-          d.se <- sqrt(sqrt(x.sd^2 / x.n)^2 + sqrt(y.sd^2 / y.n)^2)
-          df <- d.se^4 / ( sqrt(x.sd^2 / x.n)^4 / (x.n - 1) + sqrt(y.sd^2 / y.n)^4 / (y.n - 1))
-
-        }
-
-        t <- yx.diff / d.se
-        hn <- sqrt(1 / x.n + 1 / y.n)
-
-      # Reference group
-      } else {
-
-        d.se <- sqrt(sd(c(x, y))^2*(1 / x.n + 1 / y.n))
-        df <- x.n + y.n - 2
-
-        t <- yx.diff / d.se
-        hn <- sqrt(1 / x.n + 1 / y.n)
-
-      }
-
-      conf1 <- ifelse(alternative == "two.sided", (1 + conf.level) / 2, conf.level)
-      conf2 <- ifelse(alternative == "two.sided", (1 - conf.level) / 2, 1 - conf.level)
-
-      # Noncentrality parameter
-      st <- max(0.1, abs(t))
-
-      ###
-
-      end1 <- t
-      while(suppressWarnings(pt(q = t, df = df, ncp = end1)) < conf1) { end1 <- end1 - st }
-
-      ncp1 <- uniroot(function(x) conf1 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(end1, 2*t - end1))$root
-
-      ###
-
-      end2 <- t
-      while(suppressWarnings(pt(q = t, df = df, ncp = end2)) > conf2) { end2 <- end2 + st }
-
-      ncp2 <- uniroot(function(x) conf2 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(2*t - end2, end2))$root
-
-      # Confidence interval around ncp
-      conf.int <- switch(alternative,
-                         two.sided = c(low = ncp1 * hn, upp = ncp2 * hn),
-                         less = c(low = -Inf, upp = ncp2 * hn),
-                         greater = c(low = ncp1 * hn, upp = Inf))
-
-      # With correction factor
-      if(isTRUE(correct)) {
-
-        conf.int <- conf.int*corr.factor
-
-      }
-
-    # Not at least 2 observations for x/y and variance in x/y
-    } else {
-
-      d <- NA
-      conf.int <- c(NA, NA)
-
-    }
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Paired-sample ####
-  } else if (isTRUE(paired)) {
-
-    #...................
-    ### Data ####
-
-    xy.dat <- na.omit(data.frame(x = x, y = y, stringsAsFactors = FALSE))
-
-    x <- xy.dat$x
-    y <- xy.dat$y
-
-    # Standard deviation of x and y
-    x.sd <- sd(x)
-    y.sd <- sd(y)
-
-    # Unstandardized mean difference
-    yx.diff <- mean(y - x)
-
-    # Sample size
-    xy.n <- nrow(xy.dat)
-
-    #...................
-    ### Standard deviation ####
-
-    # SD of difference score, Cohen's d.z
-    if (isTRUE(weighted)) {
-
-        sd.group <- sd(y - x)
-
-    } else {
-
-      # Controlling correlation, Cohen's d.rm
-      if (isTRUE(cor)) {
-
-        # Variance of x and y
-        x.var <- var(x)
-        y.var <- var(y)
-
-        # Sum of the variances
-        xy.var.sum <- sum(c(x.var, y.var))
-
-        # Correlation between x and y
-        xy.r <- cor(x, y)
-
-         sd.group <- sqrt(xy.var.sum - 2L * xy.r * prod(c(sqrt(x.var), sqrt(y.var))))
-
-       # Ignoring correlation, Cohen's d.av
-       } else {
-
-         sd.group <- (x.sd + y.sd) / 2
-
-       }
-
-    }
-
-    #...................
-    ### Cohen's d ####
-
-    # Cohen's d.rm
-    if (isTRUE(cor && !isTRUE(weighted))) {
-
-      d <- yx.diff / sd.group * sqrt(2L*(1L -xy.r))
-
-    # Cohen's d.z, d.av, and Glass's delta
-    } else {
-
-      d <- yx.diff / sd.group
-
-    }
-
-    #...................
-    ### Correction factor ####
-
-    # Degrees of freedom
-    v <- xy.n - 1
-
-    # Correction factor based on gamma function
-    corr.factor <- gamma(0.5*v) / ((sqrt(v / 2L)) * gamma(0.5 * (v - 1L)))
-
-    # Correction factor based on approximation method
-    if (isTRUE(is.na(corr.factor) || is.nan(corr.factor) || is.infinite(corr.factor))) {
-
-      corr.factor <- 1L - 3L / (4L * v - 1L)
-
-    }
-
-    # Bias-corrected Cohen's d
-    if (isTRUE(correct)) {
-
-      d <- d*corr.factor
-
-    }
-
-    #...................
-    ### Confidence interval ####
-
-    # Standard error
-    d.se <- sqrt((xy.n / (xy.n / 2)^2) + 0.5*(d^2 / xy.n))
-
-    # Noncentrality parameter
-    t <- yx.diff / (sd.group / sqrt(xy.n))
-    df <- xy.n - 1
-
-    conf1 <- ifelse(alternative == "two.sided", (1L + conf.level) / 2L, conf.level)
-    conf2 <- ifelse(alternative == "two.sided", (1L - conf.level) / 2L, 1L - conf.level)
-
-    st <- max(0.1, abs(t))
-
-    ###
-
-    end1 <- t
-    while(suppressWarnings(pt(q = t, df = df, ncp = end1)) < conf1) { end1 <- end1 - st }
-
-    ncp1 <- uniroot(function(x) conf1 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(end1, 2*t - end1))$root
-
-    ###
-
-    end2 <- t
-    while(suppressWarnings(pt(q = t, df = df, ncp = end2)) > conf2) { end2 <- end2 + st }
-
-    ncp2 <- uniroot(function(x) conf2 - suppressWarnings(pt(q = t, df = df, ncp = x)), c(2*t - end2, end2))$root
-
-    # Confidence interval around ncp
-    conf.int <- switch(alternative,
-                       two.sided = c(low = ncp1 / sqrt(df), upp = ncp2 / sqrt(df)),
-                       less = c(low = -Inf, upp = ncp2 / sqrt(df)),
-                       greater = c(low = ncp1 / sqrt(df), upp = Inf))
-
-    # With correction factor
-    if(isTRUE(correct)) {
-
-      conf.int <- conf.int*corr.factor
-
-    }
-
-  }
-
-  # Return object
-  object <- data.frame(m.diff = yx.diff, sd = sd.group,
-                       d = d, se = d.se,
-                       low = conf.int[1L], upp = conf.int[2], row.names = NULL)
-
-  return(object)
-
-}
-
 #_______________________________________________________________________________
 #
 # Default S3 method ------------------------------------------------------------
@@ -825,7 +361,7 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
 
     if (isTRUE(is.null(dim(x)))) {
 
-      xy  <- data.frame(x = x, stringsAsFactors = FALSE)
+      xy  <- data.frame(x = x)
 
     } else {
 
@@ -843,7 +379,7 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
   ### Paired-sample design ####
   } else if (isTRUE(paired)) {
 
-    xy <- data.frame(x = x, y = y, stringsAsFactors = FALSE)
+    xy <- data.frame(x = x, y = y)
 
   }
 
@@ -855,46 +391,22 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Listwise deletion ####
 
-  if (isTRUE(paired && nrow(na.omit(xy)) < 2L)) { stop("After listwise deletion, the number of pairs of observations is less than two.", call. = FALSE)
-
-  }
+  if (isTRUE(paired && nrow(na.omit(xy)) < 2L)) { stop("After listwise deletion, the number of pairs of observations is less than two.", call. = FALSE) }
 
   #_____________________________________________________________________________
   #
   # Input Check ----------------------------------------------------------------
 
-  # Check input 'check'
-  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
+  # Check inputs
+  .check.input(logical = c("weighted", "cor", "correct", "sort.var", "append", "output"),
+               numeric = list(mu = 1L),
+               args = c("alternative", "conf.level", "digits", "write1"), envir = environment(), input.check = check)
 
+  # Additional checks
   if (isTRUE(check)) {
 
-    # Check input 'weighted'
-    if (isTRUE(!is.logical(weighted))) { stop("Please specify TRUE or FALSE for the argument 'weighted'.", call. = FALSE) }
-
-    # Check input 'cor'
-    if (isTRUE(!is.logical(cor))) { stop("Please specify TRUE or FALSE for the argument 'cor'.", call. = FALSE) }
-
     # Check input 'ref'
-    if (isTRUE(!is.null(ref))) {
-
-      if (isTRUE(!isTRUE(ref %in% c("x", "y")))) { stop("Please specify \"x\" or \"y\" for the argument 'ref'.", call. = FALSE) }
-
-    }
-
-    # Check input 'correct'
-    if (isTRUE(!is.logical(correct))) { stop("Please specify TRUE or FALSE for the argument 'correct'.", call. = FALSE) }
-
-    # Check input 'alternative'
-    if (isTRUE(!all(alternative %in%  c("two.sided", "less", "greater")))) {
-
-      stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".", call. = FALSE)
-
-    }
-
-    # Check input 'conf.level'
-    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) { stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.null(ref))) { if (isTRUE(!isTRUE(ref %in% c("x", "y")))) { stop("Please specify \"x\" or \"y\" for the argument 'ref'.", call. = FALSE) } }
 
     # Check input 'group'
     if (isTRUE(!is.null(group))) {
@@ -918,21 +430,6 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
 
     }
 
-    # Check input 'sort.var'
-    if (isTRUE(!is.logical(sort.var))) { stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE) }
-
-    # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Please specify a positive integer number for the argument 'digits'.", call. = FALSE) }
-
-    # Check input 'write'
-    if (isTRUE(!is.null(write) && substr(write, nchar(write) - 3L, nchar(write)) != ".txt")) { stop("Please specify a character string with file extenstion '.txt' for the argument 'write'.") }
-
-    # Check input 'append'
-    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
-
-    # Check input output
-    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
-
   }
 
   #_____________________________________________________________________________
@@ -1076,7 +573,7 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
 
     result <- data.frame(group = rep(names(object.group), each = ncol(xy)),
                          eval(parse(text = paste0("rbind(", paste0("object.group[[", seq_len(length(object.group)), "]]",
-                                                                   collapse = ", "), ")"))), stringsAsFactors = FALSE)
+                                                                   collapse = ", "), ")"))))
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## No Grouping, Split ####
@@ -1113,7 +610,7 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
     ### One-sample ####
     if (isTRUE(sample == "one")) {
 
-      result <- lapply(split(data.frame(xy, .group = group, stringsAsFactors = FALSE, row.names = NULL), f = split),
+      result <- lapply(split(data.frame(xy, .group = group, row.names = NULL), f = split),
                        function(z) cohens.d.default(eval(parse(text = "z[, -grep('.group', names(z))]")), y = NULL,
                                                     mu = mu, paired = paired, weighted = weighted,
                                                     cor = cor, ref = ref, correct = correct, alternative = alternative,
@@ -1124,7 +621,7 @@ cohens.d.default <- function(x, y = NULL, mu = 0, paired = FALSE, weighted = TRU
     ### Two-sample and Paired-sample ####
     } else {
 
-      result <- lapply(split(data.frame(xy, .group = group, stringsAsFactors = FALSE, row.names = NULL), f = split),
+      result <- lapply(split(data.frame(xy, .group = group, row.names = NULL), f = split),
                        function(z) cohens.d.default(x = z$x, y = z$y, mu = mu, paired = paired, weighted = weighted,
                                                     cor = cor, ref = ref, correct = correct, alternative = alternative,
                                                     conf.level = conf.level, group = z$.group, split = NULL, sort.var = sort.var,
@@ -1235,7 +732,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## As data frame ####
 
-  data <- as.data.frame(data, stringsAsFactors = FALSE)
+  data <- as.data.frame(data)
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Variables ####
@@ -1252,10 +749,8 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   ## Check ####
 
   # Check if variables are in the data
-  var.data <- !var.formula %in% colnames(data)
-  if (isTRUE(any(var.data))) {
-
-    stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE) }
+  (!var.formula %in% colnames(data)) |>
+    (\(y) if (isTRUE(any(y))) { stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(y)], collapse = ", ")), call. = FALSE) })()
 
   # Check if input 'formula' has only one grouping variable
   if (isTRUE(length(group.var) != 1L)) { stop("Please specify a formula with only one grouping variable.", call. = FALSE) }
@@ -1264,11 +759,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   if (isTRUE(length(na.omit(unique(data[, group.var]))) != 2L)) { stop("Please specify a grouping variable with exactly two levels.", call. = FALSE) }
 
   # Check if 'ref' is in the grouping variable
-  if (!isTRUE(is.null(ref))) {
-
-    if (!isTRUE(ref %in% data[, group.var])) { stop("Reference group specified in the argument 'ref' is not represented in the grouping variable.", call. = FALSE) }
-
-  }
+  if (!isTRUE(is.null(ref))) { if (!isTRUE(ref %in% data[, group.var])) { stop("Reference group specified in the argument 'ref' is not represented in the grouping variable.", call. = FALSE) } }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Convert user-missing values into NA ####
@@ -1279,8 +770,8 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
     data[, y.vars] <- misty::as.na(data[, y.vars], na = as.na, check = check)
 
     # Variable with missing values only
-    data.miss <- vapply(data[, y.vars, drop = FALSE], function(y) all(is.na(y)), FUN.VALUE = logical(1L))
-    if (any(data.miss)) { stop(paste0("After converting user-missing values into NA, following variables are completely missing: ", paste(names(which(data.miss)), collapse = ", ")), call. = FALSE) }
+    vapply(data[, y.vars, drop = FALSE], function(y) all(is.na(y)), FUN.VALUE = logical(1L)) |>
+      (\(y) if (any(y)) { stop(paste0("After converting user-missing values into NA, following variables are completely missing: ", paste(names(which(y)), collapse = ", ")), call. = FALSE) })()
 
   }
 
@@ -1293,7 +784,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
     ### No group and split variable ####
     if (isTRUE(is.null(group) && is.null(split))) {
 
-      x <- na.omit(as.data.frame(data[, var.formula], stringsAsFactors = FALSE))
+      x <- na.omit(as.data.frame(data[, var.formula]))
 
       warning(paste0("Listwise deletion of incomplete data, number of cases removed from the analysis: ", length(attributes(x)$na.action)), call. = FALSE)
 
@@ -1301,7 +792,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
     ### Group variable, no split variable ####
     } else if (isTRUE(!is.null(group) && is.null(split))) {
 
-      data.group <- na.omit(data.frame(data[, var.formula], group = group, stringsAsFactors = FALSE))
+      data.group <- na.omit(data.frame(data[, var.formula], group = group))
 
       data <- data.group[, -grep("group", names(data.group)), drop = FALSE]
       group <- data.group$group
@@ -1312,7 +803,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
     ### No group variable, split variable ####
     } else if (isTRUE(is.null(group) && !is.null(split))) {
 
-      data.split <- na.omit(data.frame(data[, var.formula], split = split, stringsAsFactors = FALSE))
+      data.split <- na.omit(data.frame(data[, var.formula], split = split))
 
       data <- data.split[, -grep("split", names(data.split)), drop = FALSE]
       split <- data.split$split
@@ -1323,7 +814,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
     ### Group variable, split variable ####
     } else if (isTRUE(!is.null(group) && !is.null(split))) {
 
-      data.group.split <- na.omit(data.frame(data[, var.formula], group = group, split = split, stringsAsFactors = FALSE))
+      data.group.split <- na.omit(data.frame(data[, var.formula], group = group, split = split))
 
       data <- data.group.split[,  !names(data.group.split) %in% c("group", "split"), drop = FALSE]
       group <- data.group.split$group
@@ -1369,9 +860,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   ## No Grouping, No Split ####
   if (isTRUE(is.null(group) && is.null(split))) {
 
-    result <- data.frame(matrix(NA, ncol = 11L, nrow = length(y.vars)*2,
-                                dimnames = list(NULL, c("variable", "between", "n", "nNA", "m", "m.diff", "sd", "d", "se", "low", "upp"))),
-                         stringsAsFactors = FALSE)
+    result <- data.frame(matrix(NA, ncol = 11L, nrow = length(y.vars)*2L, dimnames = list(NULL, c("variable", "between", "n", "nNA", "m", "m.diff", "sd", "d", "se", "low", "upp"))))
 
     loop.mat <- matrix(1:(length(y.vars)*2), ncol = 2L, byrow = TRUE)
 
@@ -1404,8 +893,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
                                                              ref = ref, correct = correct, alternative = alternative,
                                                              conf.level = conf.level, group = NULL, split = NULL,
                                                              sort.var = sort.var, digits = digits, as.na = NULL,
-                                                             check = check, output = FALSE)$result[, -1L],
-                                            stringsAsFactors = FALSE)
+                                                             check = check, output = FALSE)$result[, -1L])
 
       result[loop.mat[i, ], "between"] <- names(data.split)
 
@@ -1424,7 +912,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
 
     result <- data.frame(group = rep(names(object.group), each = length(y.vars)*2),
                          eval(parse(text = paste0("rbind(", paste0("object.group[[", seq_len(length(object.group)), "]]",
-                                                                   collapse = ", "), ")"))), stringsAsFactors = FALSE)
+                                                                   collapse = ", "), ")"))))
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## No Grouping, Split ####
@@ -1441,7 +929,7 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   ## Grouping, Split ####
   } else if (isTRUE(!is.null(group) && !is.null(split))) {
 
-    result <- lapply(split(data.frame(data[, var.formula], .group = group, stringsAsFactors = FALSE), f = split),
+    result <- lapply(split(data.frame(data[, var.formula], .group = group), f = split),
                      function(y) cohens.d.formula(formula, data = y, weighted = weighted, cor = cor,
                                                   ref = ref, correct = correct, alternative = alternative,
                                                   conf.level = conf.level, group = y$.group, split = NULL,
@@ -1499,3 +987,5 @@ cohens.d.formula <- function(formula, data, weighted = TRUE, cor = TRUE,
   return(invisible(object))
 
 }
+
+#_______________________________________________________________________________
