@@ -3,17 +3,12 @@
 #' This function recodes numeric vectors, character vectors, or factors according
 #' to recode specifications.
 #'
-#' @param ...       a numeric vector, character vector, factor, matrix or data
-#'                  frame. Alternatively, an expression indicating the variable
-#'                  names in \code{data} e.g., \code{rec(x1, x2, x3, data = dat,
-#'                  spec = "1 = 0"))}. Note that the operators \code{.}, \code{+},
-#'                  \code{-}, \code{~}, \code{:}, \code{::}, and \code{!} can also
-#'                  be used to select variables, see 'Details' in the
-#'                  \code{\link{df.subset}} function.
-#' @param data      a data frame when specifying one or more variables in the
-#'                  argument \code{...}. Note that the argument is \code{NULL}
-#'                  when specifying a a numeric vector, character vector, factor,
-#'                  matrix or data frame for the argument \code{...}.
+#' @param data      a numeric vector, character vector, factor, or data frame.
+#' @param ...       an expression indicating the variable names in \code{data},
+#'                  e.g., \code{rec(dat, x1, x2, x3, spec = "1 = 0"))}. Note that
+#'                  the operators \code{.}, \code{+}, \code{-}, \code{~}, \code{:},
+#'                  \code{::}, and \code{!} can also be used to select variables,
+#'                  see 'Details' in the \code{\link{df.subset}} function.
 #' @param spec      a character string of recode specifications (see 'Details').
 #' @param as.factor logical: if \code{TRUE}, character vector will be coerced to
 #'                  a factor.
@@ -26,13 +21,13 @@
 #'                  the ending \code{".r"} resulting in e.g. \code{"x1.r"} and
 #'                  \code{"x2.r"}. Variable names can also be specified using a
 #'                  character vector matching the number of variables specified
-#'                  in \code{...} (e.g., \code{name = c("recode.x1", "recode.x2")}).
+#'                  in \code{data} (e.g., \code{name = c("recode.x1", "recode.x2")}).
 #' @param as.na     a numeric vector indicating user-defined missing values,
 #'                  i.e. these values are converted to \code{NA} before conducting
 #'                  the analysis.
 #' @param table     logical: if \code{TRUE}, a cross table variable x recoded
 #'                  variable is printed on the console if only one variable is
-#'                  specified in \code{...}.
+#'                  specified in \code{data}.
 #' @param check     logical: if \code{TRUE} (default), argument specification is
 #'                  checked.
 #'
@@ -68,7 +63,7 @@
 #'
 #' @return
 #' Returns a numeric vector or data frame with the same length or same number of
-#' rows as \code{...} containing the recoded coded variable(s).
+#' rows as \code{data} containing the recoded coded variable(s).
 #'
 #' @note
 #' This function was adapted from the \code{recode()} function in the \pkg{car}
@@ -129,26 +124,27 @@
 #' cbind(dat, rec(dat[, c("x1.num", "x2.num")], spec = "5 = 50; 19 = 190"))
 #'
 #' # Alternative specification using the 'data' argument,
-#' rec(x1.num, x2.num, data = dat, spec = "5 = 50; 19 = 190")
+#' rec(dat, x1.num, x2.num, spec = "5 = 50; 19 = 190")
 #'
 #' # Example 4b: Recode character vector and attach to 'dat'
 #' cbind(dat, rec(dat[, c("x1.chr", "x2.chr")], spec = "'a' = 'X'"))
 #'
 #' # Example 4c: Recode factor vector and attach to 'dat'
 #' cbind(dat, rec(dat[, c("x1.fac", "x2.fac")], spec = "'a' = 'X'"))
-rec <- function(..., data = NULL, spec, as.factor = FALSE, levels = NULL,
+rec <- function(data, ..., spec, as.factor = FALSE, levels = NULL,
                 append = TRUE, name = ".e", as.na = NULL, table = FALSE,
                 check = TRUE) {
 
+
   #_____________________________________________________________________________
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input '...' is missing
-  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
+  # Check if input 'data' is missing
+  if (isTRUE(missing(data))) { stop("Please specify a a numeric vector, character vector, factor, or data frame for the argument 'data'", call. = FALSE) }
 
-  # Check if input '...' is NULL
-  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+  # Check if input 'data' is NULL
+  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
 
   # Check if input 'spec' is missing
   if (isTRUE(missing(spec))) { stop("Please specify a character string for the argument 'spec'.", call. = FALSE) }
@@ -163,32 +159,26 @@ rec <- function(..., data = NULL, spec, as.factor = FALSE, levels = NULL,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Data using the argument 'data' ####
 
-  if (isTRUE(!is.null(data))) {
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(data), 1L, 3L))) { data <- as.data.frame(data) }
+  if (isTRUE(!missing(...))) {
 
     # Variable names
-    var.names <- .var.names(..., data = data, check.chr = "a vector, factor, matrix, array, data frame, or list")
+    var.names <- .var.names(..., data = data)
 
-    # Extract variables
-    x <- data[, var.names]
+    # Extract data and convert tibble into data frame or vector
+    x <- data[, var.names] |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Data without using the argument 'data' ####
 
   } else {
 
-    # Extract data
-    x <- eval(..., enclos = parent.frame())
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(x), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(x)) == 1L)) { x <- unlist(x) } else { x <- as.data.frame(x) } }
+    # Convert 'data' as tibble into data frame
+    x <- data |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
   }
 
-  # Convert 'x' into a vector when only one variable specified in 'x'
-  if (isTRUE(ncol(data.frame(x)) == 1L)) { x <- unlist(x, use.names = FALSE) }
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Convert user-missing values into NA ####
 
   # Convert user-missing values into NA
   if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
@@ -208,7 +198,7 @@ rec <- function(..., data = NULL, spec, as.factor = FALSE, levels = NULL,
 
       if (isTRUE(!is.character(name))) { stop("Please specify a character string or vector for the argument 'name'.", call. = FALSE) }
 
-      if (isTRUE(length(name) > 1L && length(name) != ncol(x))) { stop("The length of the vector specified in 'name' does not match with the number of variable in 'x'.", call. = FALSE) }
+      if (isTRUE(length(name) > 1L && length(name) != ncol(x))) { stop("The length of the vector specified in 'name' does not match with the number of variable in 'data'.", call. = FALSE) }
 
     }
 
@@ -425,7 +415,7 @@ rec <- function(..., data = NULL, spec, as.factor = FALSE, levels = NULL,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Append ####
 
-  if (isTRUE(!is.null(data) && append)) {
+  if (isTRUE(!missing(...) && append)) {
 
     if (isTRUE(is.null(dim(x)))) {
 
