@@ -1,7 +1,8 @@
 #' Levene's Test for Homogeneity of Variance
 #'
 #' This function performs Levene's test for homogeneity of variance across two
-#' or more independent groups.
+#' or more independent groups including a plot showing violin plots and boxplots
+#' representing the distribution of the outcome variable for each group.
 #'
 #' Levene's test is equivalent to a one-way analysis of variance (ANOVA) with the
 #' absolute deviations of observations from the mean of each group as dependent
@@ -22,30 +23,41 @@
 #'                      to compute the Levene's test based on the median (aka
 #'                      Brown-Forsythe test) or \code{method = "mean"} to compute
 #'                      the Levene's test based on the arithmetic mean.
-#' @param as.na         a numeric vector indicating user-defined missing values,
-#'                      i.e. these values are converted to \code{NA} before
-#'                      conducting the analysis.
 #' @param conf.level    a numeric value between 0 and 1 indicating the confidence
 #'                      level of the interval.
 #' @param hypo          logical: if \code{TRUE} (default), null and alternative
 #'                      hypothesis are shown on the console.
 #' @param descript      logical: if \code{TRUE} (default), descriptive statistics
 #'                      are shown on the console.
-#' @param plot          logical: if \code{TRUE}, a plot showing violin plots with
+#' @param digits        an integer value indicating the number of decimal places
+#'                      to be used for displaying results.
+#' @param p.digits      an integer value indicating the number of decimal places
+#'                      to be used for displaying the \emph{p}-value.
+#' @param as.na         a numeric vector indicating user-defined missing values,
+#'                      i.e. these values are converted to \code{NA} before
+#'                      conducting the analysis.
+#' @param plot          logical: if \code{TRUE}, a plot showing violins with
 #'                      boxplots is drawn.
-#' @param violin.alpha  a numeric value indicating the opacity of the violins.
-#' @param violin.trim   logical: if \code{TRUE}, the tails of the violins to the
-#'                      range of the data is trimmed.
+#' @param violin        logical: if \code{TRUE} (default), violins are drawn.
 #' @param box           logical: if \code{TRUE} (default), boxplots are drawn.
-#' @param box.alpha     a numeric value indicating the opacity of the boxplots.
-#' @param box.width     a numeric value indicating the width of the boxplots.
 #' @param jitter        logical: if \code{TRUE} (default), jittered data points
 #'                      are drawn.
+#' @param violin.alpha  a numeric value between 0 and 1 for specifying the
+#'                      \code{alpha} argument in the \code{geom_violin}
+#'                      function for controlling the opacity of the violins.
+#' @param violin.trim   logical: if \code{TRUE}, the tails of the violins to the
+#'                      range of the data is trimmed.
+#' @param box.alpha     a numeric value between 0 and 1 for specifying the
+#'                      \code{alpha} argument in the \code{geom_boxplot}
+#'                      function for controlling the opacity of the boxplots.
+#' @param box.width     a numeric value indicating the width of the boxplots.
 #' @param jitter.size   a numeric value indicating the \code{size} aesthetic
 #'                      for the jittered data points.
 #' @param jitter.width  a numeric value indicating the amount of horizontal jitter.
 #' @param jitter.height a numeric value indicating the amount of vertical jitter.
-#' @param jitter.alpha  a numeric value indicating the opacity of the jittered
+#' @param jitter.alpha  a numeric value between 0 and 1 for specifying the
+#'                      \code{alpha} argument in the \code{geom_jitter}
+#'                      function for controlling the opacity of the jittered
 #'                      data points.
 #' @param gray          logical: if \code{TRUE}, the plot is drawn in gray scale.
 #' @param start         a numeric value between 0 and 1, graphical parameter to
@@ -59,16 +71,31 @@
 #' @param ylab          a character string specifying the labels for the y-axis.
 #' @param ylim          a numeric vector of length two specifying limits of the
 #'                      limits of the y-axis.
-#' @param breaks        a numeric vector specifying the points at which tick-marks
+#' @param ybreaks       a numeric vector specifying the points at which tick-marks
 #'                      are drawn at the y-axis.
 #' @param title         a character string specifying the text for the title for
 #'                      the plot.
 #' @param subtitle      a character string specifying the text for the subtitle
 #'                      for the plot.
-#' @param digits        an integer value indicating the number of decimal places
-#'                      to be used for displaying results.
-#' @param p.digits      an integer value indicating the number of decimal places
-#'                      to be used for displaying the \emph{p}-value.
+#' @param filename      a character string indicating the \code{filename}
+#'                      argument including the file extension in the \code{ggsave}
+#'                      function. Note that one of \code{".eps"}, \code{".ps"},
+#'                      \code{".tex"}, \code{".pdf"} (default),
+#'                      \code{".jpeg"}, \code{".tiff"}, \code{".png"},
+#'                      \code{".bmp"}, \code{".svg"} or \code{".wmf"} needs
+#'                      to be specified as file extension in the \code{file}
+#'                      argument. Note that plots can only be saved when
+#'                      \code{plot = TRUE}.
+#' @param width         a numeric value indicating the \code{width} argument
+#'                      (default is the size of the current graphics device)
+#'                      for the \code{ggsave} function.
+#' @param height        a numeric value indicating the \code{height} argument
+#'                      (default is the size of the current graphics device)
+#'                      for the \code{ggsave} function.
+#' @param units         a character string indicating the \code{units} argument
+#'                      (default is \code{in}) for the \code{ggsave} function.
+#' @param dpi           a numeric value indicating the \code{dpi} argument
+#'                      (default is \code{600}) for the \code{ggsave} function.
 #' @param write         a character string naming a text file with file extension
 #'                      \code{".txt"} (e.g., \code{"Output.txt"}) for writing the
 #'                      output into a text file.
@@ -99,8 +126,8 @@
 #' entries:
 #' \item{\code{call}}{function call}
 #' \item{\code{type}}{type of analysis}
-#' \item{\code{formula}}{formula}
 #' \item{\code{data}}{data frame with the outcome and grouping variable}
+#' \item{\code{formula}}{formula}
 #' \item{\code{args}}{specification of function arguments}
 #' \item{\code{plot}}{ggplot2 object for plotting the results}
 #' \item{\code{result}}{result table}
@@ -114,46 +141,28 @@
 #' # Example 2: Levene's test based on the arithmetic mean
 #' test.levene(mpg ~ gear, data = mtcars, method = "mean")
 #'
-#' # Example 3: Write results into a text file
-#' test.levene(mpg ~ gear, data = mtcars, write = "Levene.txt")
-#'
-#' # Example 4: Levene's test based on the median,
-#' # plot results
+#' # Example 3: Levene's test based on the median, plot results
 #' test.levene(mpg ~ gear, data = mtcars, plot = TRUE)
 #'
-#' # Load ggplot2 package
-#' library(ggplot2)
-#'
-#' # Save plot, ggsave() from the ggplot2 package
-#' ggsave("Levene-test.png", dpi = 600, width = 5, height = 6)
-#'
-#' # Levene's test based on the median
-#' # extract plot
-#' p <- test.levene(mpg ~ gear, data = mtcars, output = FALSE)$plot
-#' p
-#'
-#' # Example 5: Levene's test based on the median
-#' # Draw violin and boxplots in line with the default setting of test.levene()
-#'
-#' # Extract data
-#' plotdat <- test.levene(mpg ~ gear, data = mtcars, output = FALSE)$data
-#'
-#' # Draw violin and boxplots
-#' ggplot(plotdat, aes(group, y, fill = group)) +
-#'   geom_violin(alpha = 0.3, trim = FALSE) +
-#'   geom_boxplot(alpha = 0.2, width = 0.2) +
-#'   geom_jitter(alpha = 0.2, width = 0.05, size = 1.25) +
-#'   theme_bw() + guides(fill = "none")
+#' \dontrun{
+#' # Example 4: Write results into a text file
+#' test.levene(mpg ~ gear, data = mtcars, write = "Levene.txt")
+
+#' # Example 5: Levene's test based on the median, save plot
+#' test.levene(mpg ~ gear, data = mtcars, plot = TRUE,
+#'             filename = "Levene-test.png", dpi = 600, width = 6, height = 5)
+#' }
 test.levene <- function(formula, data, method = c("median", "mean"),
                         conf.level = 0.95, hypo = TRUE, descript = TRUE,
-                        plot = FALSE, violin.alpha = 0.3, violin.trim = FALSE,
-                        box = TRUE, box.alpha = 0.2, box.width = 0.2,
-                        jitter = TRUE, jitter.size = 1.25, jitter.width = 0.05,
-                        jitter.height = 0, jitter.alpha = 0.2,
-                        gray = FALSE, start = 0.9, end = 0.4, color = NULL,
-                        xlab = NULL, ylab = NULL, ylim = NULL, breaks = ggplot2::waiver(),
-                        title = "", subtitle = "", digits = 2, p.digits = 3, as.na = NULL,
-                        write = NULL, append = TRUE, check = TRUE, output = TRUE) {
+                        digits = 2, p.digits = 3, as.na = NULL, plot = FALSE,
+                        violin = TRUE, box = TRUE, jitter = FALSE, violin.alpha = 0.3,
+                        violin.trim = FALSE, box.alpha = 0.2, box.width = 0.2,
+                        jitter.size = 1.25, jitter.width = 0.05, jitter.height = 0,
+                        jitter.alpha = 0.2, gray = FALSE, start = 0.9, end = 0.4,
+                        color = NULL, xlab = NULL, ylab = NULL, ylim = NULL,
+                        ybreaks = ggplot2::waiver(), title = "", subtitle = "",
+                        filename = NULL, width = NA, height = NA, units = c("in", "cm", "mm", "px"),
+                        dpi = 600, write = NULL, append = TRUE, check = TRUE, output = TRUE) {
 
   #_____________________________________________________________________________
   #
@@ -190,12 +199,7 @@ test.levene <- function(formula, data, method = c("median", "mean"),
   data <- as.data.frame(data)
 
   # Check if variables are in the data
-  var.data <- !var.formula %in% colnames(data)
-  if (isTRUE(any(var.data))) {
-
-    stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE)
-
-  }
+  (!var.formula %in% colnames(data)) |> (\(y) if (isTRUE(any(y))) { stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(y)], collapse = ", ")), call. = FALSE) })()
 
   # Check if input 'formula' has only one grouping variable
   if (isTRUE(length(y.var) != 1L)) { stop("Please specify a formula with only one outcome variable.", call. = FALSE) }
@@ -218,22 +222,22 @@ test.levene <- function(formula, data, method = c("median", "mean"),
   # Input Check ----------------------------------------------------------------
 
   # Check inputs
-  .check.input(logical = c("hypo", "descript", "plot", "violin.trim", "box", "jitter", "gray", "append", "output"),
+  .check.input(logical = c("hypo", "descript", "plot", "violin", "box", "jitter", "violin.trim", "gray", "append", "output"),
                numeric = list(violin.alpha = 1L, box.alpha = 1L, box.width = 1L, jitter.size = 1L, jitter.width = 1L, jitter.height = 1L, jitter.alpha = 1L, start = 1L, end = 1L, ylim = 2L),
                character = list(xlab = 1L, ylab = 1L, title = 1L, subtitle = 1L),
                s.character = list(method = c("median", "mean")),
-               args = c("conf.level", "digits", "p.digits", "write1"),
-               package = "ggplot2", envir = environment(), input.check = check)
+               args = c("conf.level", "digits", "p.digits", "write1"), envir = environment(), input.check = check)
 
   # Additional checks
   if (isTRUE(check)) {
 
+    # Package ggplot2
+    if (isTRUE(plot)) { if (isTRUE(!nzchar(system.file(package = "ggplot2")))) { stop("Package \"ggplot2\" is needed to draw a plot, please install the package.", call. = FALSE) } }
+
     # Variance zero
-    y.var0 <- tapply(data[, y.var], data[, group.var], var, na.rm = TRUE) == 0L
+    (tapply(data[, y.var], data[, group.var], var, na.rm = TRUE) == 0L) |> (\(y) if (isTRUE(any(y))) { stop(paste0("There are groups with 0 variance: Group ", paste(which(y), collapse = ", ")), call. = FALSE) })()
 
-    if (isTRUE(any(y.var0))) { stop(paste0("There are groups with 0 variance: Group ", paste(which(y.var0), collapse = ", ")), call. = FALSE) }
-
-     # Check input 'start'
+    # Check input 'start'
     if (isTRUE(start < 0L || start > 1L)) { stop("Please specify a numeric value between 0 and 1 for the argument 'start'", call. = FALSE) }
 
     # Check input 'end'
@@ -282,78 +286,42 @@ test.levene <- function(formula, data, method = c("median", "mean"),
   })
 
   # Deviation from the median or mean
-  y.dev <- abs(y -  y.center[match(group, names(y.center))])
+  y.dev <- abs(y - y.center[match(group, names(y.center))])
 
   # Analysis of Variance
   result.aov <- summary(aov(y.dev ~ as.factor(group)))[[1L]]
 
   row.names(result.aov) <- c("Group", "Residuals")
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Plot ####
-
-  #...................
-  ### Plot data ####
-
-  plotdat <- data.frame(group = factor(group), y = y, row.names = NULL)
-
-  #...................
-  ### Create plot ####
-
-  p <- ggplot2::ggplot(plotdat, ggplot2::aes(group, y, fill = group)) +
-         ggplot2::geom_violin(alpha = violin.alpha, trim = violin.trim) +
-         ggplot2::scale_x_discrete(name = xlab) +
-         ggplot2::scale_y_continuous(name = ylab, limits = ylim, breaks = breaks) +
-         ggplot2::theme_bw() +
-         ggplot2::labs(title = title, subtitle = subtitle) +
-         ggplot2::theme(plot.subtitle = ggplot2::element_text(hjust = 0.5),
-                        plot.title = ggplot2::element_text(hjust = 0.5)) +
-         ggplot2::guides(fill = "none")
-
-  # Add boxplots
-  if (isTRUE(box)) { p <- p + ggplot2::geom_boxplot(alpha = box.alpha, width = box.width) }
-
-  # Add jittered points
-  if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, height = jitter.height, size = jitter.size) }
-
-  # Gray color scales
-  if (isTRUE(gray)) {
-
-    p <- p + ggplot2::scale_fill_grey(start = start, end = end)
-
-  # User-specified colors
-  } else {
-
-    if (isTRUE(!is.null(color))) { p <- p + ggplot2::scale_fill_manual(values = color) }
-
-  }
-
-  #......................................
-  # Print plot
-  if (isTRUE(plot)) { suppressWarnings(print(p)) }
-
   #_____________________________________________________________________________
   #
   # Return Object --------------------------------------------------------------
 
   object <- list(call = match.call(),
                  type = "test.levene",
-                 formula = formula,
                  data = data.frame(y, group = factor(group)),
+                 formula = formula,
                  args = list(method = method, conf.level = conf.level, hypo = hypo,
-                             descript = descript, plot = plot, violin.alpha = violin.alpha,
-                             violin.trim = violin.trim, box = box, box.alpha = box.alpha,
-                             box.width = box.width, jitter = jitter, jitter.size = jitter.size,
-                             jitter.width = jitter.width, jitter.height = jitter.height ,
-                             jitter.alpha = jitter.alpha, gray = gray, start = start,
-                             end = end, color = color, xlab = xlab, ylab = ylab,
-                             ylim = ylim, breaks = breaks, title = title, subtitle = subtitle,
-                             digits = digits, p.digits = p.digits, as.na = as.na,
+                             descript = descript, digits = digits, p.digits = p.digits,
+                             as.na = as.na, plot = plot, violin = violin, box = box,
+                             jitter = jitter, violin.alpha = violin.alpha, violin.trim = violin.trim,
+                             box.alpha = box.alpha, box.width = box.width, jitter.size = jitter.size,
+                             jitter.width = jitter.width, jitter.height = jitter.height,
+                             jitter.alpha = jitter.alpha, gray = gray, start = start, end = end,
+                             color = color, xlab = xlab, ylab = ylab, ylim = ylim, ybreaks = ybreaks,
+                             title = title, subtitle = subtitle, filename = filename,
+                             width = width, height = height, units = units, dpi = dpi,
                              write = write, append = append, check = check, output = output),
-                 plot = p, result = list(descript = result.ci, test = result.aov))
+                 plot = NULL, result = list(descript = result.ci, test = result.aov))
 
   class(object) <- "misty.object"
 
+  #_____________________________________________________________________________
+  #
+  # Plot and Save Results ------------------------------------------------------
+
+  if (isTRUE(plot)) { object$plot <- plot(object, filename = filename, width = width, height = height, units = units, dpi = dpi, check = FALSE) |> (\(y) suppressMessages(suppressWarnings(print(y))))() }
+
   #_____________________________________________________________________________
   #
   # Write Results --------------------------------------------------------------
@@ -363,7 +331,7 @@ test.levene <- function(formula, data, method = c("median", "mean"),
     #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     ## Text file ####
 
-    # Send R output to textfile
+    # Send R output to text file
     sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
 
     if (isTRUE(append && file.exists(write))) { write("", file = write, append = TRUE) }
