@@ -2,8 +2,8 @@
 #'
 #' This function performs Welch's two-sample t-test and Welch's ANOVA including
 #' Games-Howell post hoc test for multiple comparison and provides descriptive
-#' statistics, effect size measures, and a plot showing error bars for
-#' difference-adjusted confidence intervals with jittered data points.
+#' statistics, effect size measures, and a plot showing bars representing means
+#' for each group and error bars for difference-adjusted confidence intervals.
 #'
 #' @param formula        a formula of the form \code{y ~ group} where \code{y} is
 #'                       a numeric variable giving the data values and \code{group}
@@ -37,40 +37,59 @@
 #'                       Cohen's d.
 #' @param correct        logical: if \code{TRUE}, correction factor to remove
 #'                       positive bias in small samples is used.
-#' @param plot           logical: if \code{TRUE}, a plot showing error bars for
-#'                       confidence intervals is drawn.
+#' @param plot           logical: if \code{TRUE}, a plot is drawn.
+#' @param bar            logical: if \code{TRUE} (default), bars representing means
+#'                       for each groups are drawn.
+#' @param point          logical: if \code{TRUE}, points representing means for
+#'                       each groups are drawn.
+#' @param ci             logical: if \code{TRUE} (default), error bars representing
+#'                       confidence intervals are drawn.
+#' @param jitter         logical: if \code{TRUE}, jittered data points are drawn.
 #' @param adjust         logical: if \code{TRUE} (default), difference-adjustment
 #'                       for the confidence intervals is applied.
 #' @param point.size     a numeric value indicating the \code{size} aesthetic for
 #'                       the point representing the mean value.
 #' @param errorbar.width a numeric value indicating the horizontal bar width of
 #'                       the error bar.
+#' @param jitter.size    a numeric value indicating the \code{size} aesthetic
+#'                       for the jittered data points.
+#' @param jitter.width   a numeric value indicating the amount of horizontal jitter.
+#'                       data points.
+#' @param jitter.height  a numeric value indicating the amount of vertical jitter.
+#'                       data points.
+#' @param jitter.alpha   a numeric value between 0 and 1 for specifying the
+#'                       \code{alpha} argument in the \code{geom_jitter}
+#'                       function for controlling the opacity of the jittered
+#'                       data points.
 #' @param xlab           a character string specifying the labels for the x-axis.
 #' @param ylab           a character string specifying the labels for the y-axis.
 #' @param ylim           a numeric vector of length two specifying limits of the
 #'                       limits of the y-axis.
-#' @param breaks         a numeric vector specifying the points at which tick-marks
+#' @param ybreaks        a numeric vector specifying the points at which tick-marks
 #'                       are drawn at the y-axis.
-#' @param jitter         logical: if \code{TRUE} (default), jittered data points
-#'                       are drawn.
-#' @param jitter.size    a numeric value indicating the \code{size} aesthetic
-#'                       for the jittered data points.
-#' @param jitter.width   a numeric value indicating the amount of horizontal jitter.
-#' @param jitter.height  a numeric value indicating the amount of vertical jitter.
-#' @param jitter.alpha   a numeric value indicating the opacity of the jittered
-#'                       data points.
-#' @param title          a character string specifying the text for the title for
+#' @param title          a character string specifying the text for the title of
 #'                       the plot.
-#' @param subtitle       a character string specifying the text for the subtitle for
-#'                       the plot.
-#' @param digits         an integer value indicating the number of decimal places
-#'                       to be used for displaying descriptive statistics and
-#'                       confidence interval.
-#' @param p.digits       an integer value indicating the number of decimal places
-#'                       to be used for displaying the \emph{p}-value.
-#' @param as.na          a numeric vector indicating user-defined missing values,
-#'                       i.e. these values are converted to \code{NA} before conducting
-#'                       the analysis.
+#' @param subtitle       a character string specifying the text for the subtitle
+#'                       of the plot.
+#' @param filename       a character string indicating the \code{filename}
+#'                       argument including the file extension in the \code{ggsave}
+#'                       function. Note that one of \code{".eps"}, \code{".ps"},
+#'                       \code{".tex"}, \code{".pdf"} (default),
+#'                       \code{".jpeg"}, \code{".tiff"}, \code{".png"},
+#'                       \code{".bmp"}, \code{".svg"} or \code{".wmf"} needs
+#'                       to be specified as file extension in the \code{filename}
+#'                       argument. Note that plots can only be saved when
+#'                       \code{plot = TRUE}.
+#' @param width          a numeric value indicating the \code{width} argument
+#'                       (default is the size of the current graphics device)
+#'                       in the \code{ggsave} function.
+#' @param height         a numeric value indicating the \code{height} argument
+#'                       (default is the size of the current graphics device)
+#'                       in the \code{ggsave} function.
+#' @param units          a character string indicating the \code{units} argument
+#'                       (default is \code{in}) in the \code{ggsave} function.
+#' @param dpi            a numeric value indicating the \code{dpi} argument
+#'                       (default is \code{600}) in the \code{ggsave} function.
 #' @param write          a character string naming a text file with file extension
 #'                       \code{".txt"} (e.g., \code{"Output.txt"}) for writing the
 #'                       output into a text file.
@@ -82,7 +101,6 @@
 #'                       is checked.
 #' @param output         logical: if \code{TRUE} (default), output is shown on the
 #'                       console.
-#' @param ...            further arguments to be passed to or from methods.
 #'
 #' @details
 #' \describe{
@@ -116,8 +134,8 @@
 #' \item{\code{call}}{function call}
 #' \item{\code{type}}{type of analysis}
 #' \item{\code{sample}}{type of sample, i.e., one-, two-, or paired sample}
-#' \item{\code{formula}}{formula}
 #' \item{\code{data}}{data frame with the outcome and grouping variable}
+#' \item{\code{formula}}{formula}
 #' \item{\code{args}}{specification of function arguments}
 #' \item{\code{plot}}{ggplot2 object for plotting the results}
 #' \item{\code{result}}{result table}
@@ -134,86 +152,43 @@
 #' # Example 1b: One-sided two-sample Welch-test
 #' test.welch(mpg ~ vs, data = mtcars, alternative = "greater")
 #'
-#' # Example 1c: Two-sided two-sample Welch-test
-#' # print Cohen's d with weighted pooled SD
+#' # Example 1c: Two-sided two-sample Welch-test, print Cohen's d
 #' test.welch(mpg ~ vs, data = mtcars, effsize = TRUE)
 #'
-#' # Example 1d: Two-sided two-sample Welch-test
-#' # plot results
+#' # Example 1d: Two-sided two-sample Welch-test, plot results
 #' test.welch(mpg ~ vs, data = mtcars, plot = TRUE)
 #'
-#' # Load ggplot2 package
-#' library(ggplot2)
-#'
-#' # Save plot, ggsave() from the ggplot2 package
-#' ggsave("Two-sample_Welch-test.png", dpi = 600, width = 4, height = 6)
-#'
-#' # Example 1e: Two-sided two-sample Welch-test
-#' # extract plot
-#' p <- test.welch(mpg ~ vs, data = mtcars, output = FALSE)$plot
-#' p
-#'
-#' # Example 1f: Two-sided two-sample Welch-test
-#' # Draw plot in line with the default setting of test.welch()
-#'
-#' # Extract data
-#' plotdat <- test.welch(mpg ~ vs, data = mtcars, output = FALSE)$data
-#'
-#' # Draw plot
-#' ggplot(plotdat, aes(factor(group), y)) +
-#'   geom_point(stat = "summary", fun = "mean", size = 4) +
-#'   stat_summary(fun.data = "mean_cl_normal", geom = "errorbar", width = 0.20) +
-#'   scale_x_discrete(name = NULL) +
-#'   labs(subtitle = "Two-Sided 95% Confidence Interval") +
-#'   theme_bw() + theme(plot.subtitle = element_text(hjust = 0.5))
-#'
 #' #----------------------------------------------------------------------------
 #' # Multiple-Sample Design
 #'
 #' # Example 2a: Welch's ANOVA
 #' test.welch(mpg ~ gear, data = mtcars)
 #'
-#' # Example 2b: Welch's ANOVA
-#' # print eta-squared and omega-squared
+#' # Example 2b: Welch's ANOVA, Games-Howell post hoc test
+#' test.welch(mpg ~ gear, data = mtcars, posthoc = TRUE)
+#'
+#' # Example 2c: Welch's ANOVA, print eta-squared and omega-squared
 #' test.welch(mpg ~ gear, data = mtcars, effsize = TRUE)
 #'
-#' # Example 2c: Welch's ANOVA, plot results
+#' # Example 2d: Welch's ANOVA, plot results
 #' test.welch(mpg ~ gear, data = mtcars, plot = TRUE)
 #'
-#' # Load ggplot2 package
-#' library(ggplot2)
-#'
-#' # Save plot, ggsave() from the ggplot2 package
-#' ggsave("Multiple-sample_Welch-test.png", dpi = 600, width = 4.5, height = 6)
-#'
-#' # Example 2e: Welch's ANOVA
-#' # extract plot
-#' p <- test.welch(mpg ~ gear, data = mtcars, output = FALSE)$plot
-#' p
-#'
-#' # Example 2e: Welch's ANOVA
-#' # Draw plot in line with the default setting of test.welch()
-#'
-#' # Extract data
-#' plotdat <- test.welch(mpg ~ gear, data = mtcars, output = FALSE)$data
-#'
-#' # Draw plot
-#' ggplot(plotdat, aes(group, y)) +
-#'   geom_point(stat = "summary", fun = "mean", size = 4) +
-#'   stat_summary(fun.data = "mean_cl_normal", geom = "errorbar", width = 0.20) +
-#'   scale_x_discrete(name = NULL) +
-#'   labs(subtitle = "Two-Sided 95% Confidence Interval") +
-#'   theme_bw() + theme(plot.subtitle = element_text(hjust = 0.5))
+#' \dontrun{
+#' # Example 2e: Welch's ANOVA, save plot
+#' test.welch(mpg ~ gear, data = mtcars, plot = TRUE,
+#'            filename = "Multiple-sample_Welch-test.png", width = 6, height = 5)
+#' }
 test.welch <- function(formula, data, alternative = c("two.sided", "less", "greater"),
                        posthoc = FALSE, conf.level = 0.95, hypo = TRUE, descript = TRUE,
                        effsize = FALSE, weighted = FALSE, ref = NULL, correct = FALSE,
-                       plot = FALSE, adjust = TRUE, point.size = 4, errorbar.width = 0.1,
-                       xlab = NULL, ylab = NULL, ylim = NULL, breaks = ggplot2::waiver(),
-                       jitter = TRUE, jitter.size = 1.25, jitter.width = 0.05,
-                       jitter.height = 0, jitter.alpha = 0.1,
-                       title = "",  subtitle = "Confidence Interval",
-                       digits = 2, p.digits = 3, as.na = NULL, write = NULL, append = TRUE,
-                       check = TRUE, output = TRUE, ...) {
+                       digits = 2, p.digits = 3, as.na = NULL, plot = FALSE,
+                       bar = TRUE, point = FALSE, ci = TRUE, jitter = FALSE,
+                       adjust = TRUE, point.size = 3, errorbar.width = 0.1, jitter.size = 1.25,
+                       jitter.width = 0.05, jitter.height = 0, jitter.alpha = 0.1,
+                       xlab = NULL, ylab = "y", ylim = NULL, ybreaks = ggplot2::waiver(),
+                       title = NULL, subtitle = "Confidence Interval", filename = NULL,
+                       width = NA, height = NA, units = c("in", "cm", "mm", "px"), dpi = 600,
+                       write = NULL, append = TRUE, check = TRUE, output = TRUE) {
 
   #_____________________________________________________________________________
   #
@@ -245,22 +220,19 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   # Input Check ----------------------------------------------------------------
 
   # Check inputs
-  .check.input(logical = c("hypo", "descript", "effsize", "weighted", "correct", "plot", "jitter", "append", "output"),
+  .check.input(logical = c("posthoc", "hypo", "descript", "effsize", "weighted", "correct", "plot", "bar", "point", "ci", "jitter", "adjust", "append", "output"),
                numeric = list(point.size = 1L, errorbar.width = 1L, jitter.size = 1L, jitter.width = 1L, jitter.height = 1L, jitter.alpha = 1L, ylim = 2L),
                character = list(xlab = 1L, ylab = 1L, title = 1L, subtitle = 1L),
-               args = c("conf.level", "digits", "p.digits", "write1"),
-               package = "ggplot2", envir = environment(), input.check = check)
+               args = c("conf.level", "digits", "p.digits", "write1"), envir = environment(), input.check = check)
 
   # Additional checks
   if (isTRUE(check)) {
 
+    # Package ggplot2
+    if (isTRUE(plot)) { if (isTRUE(!nzchar(system.file(package = "ggplot2")))) { stop("Package \"ggplot2\" is needed to draw a plot, please install the package.", call. = FALSE) } }
+
     # Check if variables are in the data
-    var.data <- !var.formula %in% colnames(data)
-    if (isTRUE(any(var.data))) {
-
-      stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE)
-
-    }
+    (!var.formula %in% colnames(data)) |> (\(y) if (isTRUE(any(y))) { stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(y)], collapse = ", ")), call. = FALSE) })()
 
     # Check if input 'formula' has only one grouping variable
     if (isTRUE(length(group.var) != 1L)) { stop("Please specify a formula with only one grouping variable.", call. = FALSE) }
@@ -292,7 +264,6 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   #
   # Arguments ------------------------------------------------------------------
 
-
   # Global variables
   m <- low <- upp <- NULL
 
@@ -308,8 +279,8 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   if (isTRUE(sample == "two")) {
 
     # Descriptive statistics
-    ci <- misty::df.rename(misty::ci.mean.diff(formula = formula, data = data,  paired = FALSE, adjust = adjust, alternative = alternative, conf.level = conf.level, check = FALSE, output = FALSE)$result,
-                           from = c("between", "low", "upp"), to = c("group", "m.low", "m.upp"))
+    ci.table <- misty::df.rename(misty::ci.mean.diff(formula = formula, data = data,  paired = FALSE, adjust = adjust, alternative = alternative, conf.level = conf.level, check = FALSE, output = FALSE)$result,
+                                 from = c("between", "low", "upp"), to = c("group", "m.low", "m.upp"))
 
     # Cohen's d
     d <- misty::cohens.d(formula = formula, data = data, paired = FALSE, mu = 0L,
@@ -320,17 +291,14 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
 
     # Welch's test for two groups
     welch <- t.test(formula = formula, data = data,
-                    alternative = switch(alternative,
-                                         two.sided = "two.sided",
-                                         greater = "less",
-                                         less = "greater"),
+                    alternative = switch(alternative, two.sided = "two.sided", greater = "less", less = "greater"),
                     var.equal = FALSE)
 
     #...................
     ### Result object ####
 
-    result <- data.frame(cbind(ci[, c("group", "n", "nNA", "m", "sd", "m.diff")],
-                               se = c(NA, welch$stderr), ci[, c("m.low", "m.upp")],
+    result <- data.frame(cbind(ci.table[, c("group", "n", "nNA", "m", "sd", "m.diff")],
+                               se = c(NA, welch$stderr), ci.table[, c("m.low", "m.upp")],
                                t = c(NA, welch$statistic)*-1L, df = c(NA, welch$parameter), pval = c(NA, welch$p.value),
                                d = d$d, d.low = d$low, d.upp = d$upp),
                          row.names = NULL)
@@ -344,7 +312,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     #...................
     ### Descriptive statistics ####
 
-    ci <- misty::ci.mean(y, group = group, adjust = adjust, output = FALSE)$result[, c("group", "n", "nNA", "m", "low", "upp", "sd", "skew", "kurt")]
+    ci.table <- misty::ci.mean(y, group = group, adjust = adjust, output = FALSE)$result[, c("group", "n", "nNA", "m", "low", "upp", "sd", "skew", "kurt")]
 
     #...................
     ### ANOVA table ####
@@ -365,8 +333,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     #...................
     ### Omega squared ####
 
-    omega.sq <- (ss.m - df.m*ms.r) / (ss.t + ms.r)
-    omega.sq <- ifelse(omega.sq < 0L, 0L, omega.sq)
+    omega.sq <- (ss.m - df.m*ms.r) / (ss.t + ms.r) |> (\(y) ifelse(y < 0L, 0L, y))()
 
     #...................
     ### Welch's ANOVA ####
@@ -374,7 +341,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     welch <- oneway.test(formula = formula, data = data, var.equal = FALSE)
 
     #...................
-    ### Post-Hoc test ####
+    ### Post Hoc test ####
 
     # Generate all pairwise combinations
     combs <- combn(levels(group), m = 2L)
@@ -383,15 +350,15 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     groups <- length(levels(group))
 
     # Sample size
-    n <- setNames(ci[["n"]], ci[["group"]])
+    n <- setNames(ci.table[["n"]], ci.table[["group"]])
 
     # Mean and variance
-    means <- setNames(ci[["m"]], ci[["group"]])
-    vars <- setNames(ci[["sd"]]^2L, ci[["group"]])
+    means <- setNames(ci.table[["m"]], ci.table[["group"]])
+    vars <- setNames(ci.table[["sd"]]^2L, ci.table[["group"]])
 
     ###
     # Conduct post-hoc test
-    result.ph <- lapply(1L:ncol(combs), function(x) {
+    result.ph <- lapply(seq_len(ncol(combs)), function(x) {
 
       # Mean
       temp.m1 <- means[names(means) == combs[1L, x]]
@@ -421,12 +388,11 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
       se <- sqrt(0.5 * (temp.var1 / temp.n1 + temp.var2 / temp.n2))
 
       # Lower Confidence Limit
-      m.low <- lapply(1L:ncol(combs), function(x) { m.diff - stats::qtukey(p = 0.95, nmeans = groups, df = df) * se })[[1L]]
+      m.low <- lapply(seq_len(ncol(combs)), function(x) { m.diff - stats::qtukey(p = 0.95, nmeans = groups, df = df) * se })[[1L]]
 
       # Upper Confidence Limit
-      m.upp <- lapply(1L:ncol(combs), function(x) { m.diff + stats::qtukey(p = 0.95, nmeans = groups, df = df) * se })[[1L]]
+      m.upp <- lapply(seq_len(ncol(combs)), function(x) { m.diff + stats::qtukey(p = 0.95, nmeans = groups, df = df) * se })[[1L]]
 
-      ###
       # Cohen's d
       data.temp <- data.frame(group, y)[which(group %in% c(combs[1L, x], combs[2L, x])), ]
 
@@ -451,7 +417,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     #...................
     ### Result object ####
 
-    result <- list(descript = ci,
+    result <- list(descript = ci.table,
                    test = data.frame(F = welch$statistic,
                                      df1 = welch$parameter["num df"], df2 = welch$parameter["denom df"],
                                      pval = welch$p.value,
@@ -462,40 +428,6 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
 
   }
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Plot ####
-
-  #...................
-  ### Plot data ####
-
-  # Confidence interval
-  plot.ci <- misty::ci.mean(data[, y.var], group = data[, group.var], adjust = adjust, conf.level = conf.level, output = FALSE)$result
-
-  plotdat <-  data.frame(group = group, y = y, row.names = NULL)
-
-  # Plot Subtitle
-  if (isTRUE(subtitle == "Confidence Interval")) { subtitle <- paste0("Two-Sided ", round(conf.level * 100L, digits = 2L), "% Confidence Interval") }
-
-  # Create ggplot
-  p <- ggplot2::ggplot(plotdat, ggplot2::aes(group, y))
-
-  # Add jittered points
-  if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, height = jitter.height, size = jitter.size) }
-
-  p <- p + ggplot2::geom_point(data = plot.ci, ggplot2::aes(group, m), stat = "identity", size = point.size) +
-         ggplot2::geom_errorbar(data = plot.ci, ggplot2::aes(group, m, ymin = low, ymax = upp), width = errorbar.width) +
-         ggplot2::scale_x_discrete(name = xlab) +
-         ggplot2::scale_y_continuous(name = ylab, limits = ylim, breaks = breaks) +
-         ggplot2::theme_bw() +
-         ggplot2::labs(title = title, subtitle = subtitle) +
-         ggplot2::theme(plot.subtitle = ggplot2::element_text(hjust = 0.5),
-                        plot.title = ggplot2::element_text(hjust = 0.5))
-
-  #...................
-  ### Print plot ####
-
-  if (isTRUE(plot)) { suppressWarnings(print(p)) }
-
   #_____________________________________________________________________________
   #
   # Return Object --------------------------------------------------------------
@@ -508,16 +440,24 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
                  args = list(alternative = alternative, posthoc = posthoc,
                              conf.level = conf.level, hypo = hypo, descript = descript,
                              effsize = effsize, weighted = weighted, ref = ref, correct = correct,
-                             plot = plot, adjust = adjust, point.size = point.size, errorbar.width = errorbar.width,
-                             xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
-                             jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
-                             jitter.height = jitter.height, jitter.alpha = jitter.alpha,
-                             title = title, subtitle = subtitle, digits = digits, p.digits = p.digits,
-                             as.na = as.na, check = check, output = output),
-                 plot = p, result = result)
+                             digits = digits, p.digits = p.digits, as.na = as.na, plot = plot,
+                             bar = bar, point = point, ci = ci, jitter = jitter,
+                             adjust = adjust, point.size = point.size, errorbar.width = errorbar.width,
+                             jitter.size = jitter.size, jitter.width = jitter.width, jitter.height = jitter.height,
+                             jitter.alpha = jitter.alpha, xlab = xlab, ylab = ylab, ylim = ylim, ybreaks = ybreaks,
+                             title = title, subtitle = subtitle, filename = filename,
+                             width = width, height = height, units = units, dpi = dpi,
+                             write = write, append = append, check = check, output = output),
+                 plot = NULL, result = result)
 
   class(object) <- "misty.object"
 
+  #_____________________________________________________________________________
+  #
+  # Plot and Save Results ------------------------------------------------------
+
+  if (isTRUE(plot)) { object$plot <- plot(object, filename = filename, width = width, height = height, units = units, dpi = dpi, check = FALSE) |> (\(y) suppressMessages(suppressWarnings(print(y))))() }
+
   #_____________________________________________________________________________
   #
   # Write Results --------------------------------------------------------------
@@ -527,7 +467,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     ## Text file ####
 
-    # Send R output to textfile
+    # Send R output to text file
     sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
 
     if (isTRUE(append && file.exists(write))) { write("", file = write, append = TRUE) }
